// Copyright 2015, VIXL authors
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//   * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//   * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//   * Neither the name of ARM Limited nor the names of its contributors may be
//     used to endorse or promote products derived from this software without
//     specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


// ---------------------------------------------------------------------
// This file is auto generated using tools/generate_simulator_traces.py.
//
// PLEASE DO NOT EDIT.
// ---------------------------------------------------------------------

#ifndef VIXL_ASSEMBLER_COND_RD_RN_OPERAND_CONST_SBC_T32_H_
#define VIXL_ASSEMBLER_COND_RD_RN_OPERAND_CONST_SBC_T32_H_

const byte kInstruction_sbc_al_r13_r14_0x02ac0000[] = {
  0x6e, 0xf1, 0x2b, 0x7d // sbc al r13 r14 0x02ac0000
};
const byte kInstruction_sbc_al_r10_r1_0x00156000[] = {
  0x61, 0xf5, 0xab, 0x1a // sbc al r10 r1 0x00156000
};
const byte kInstruction_sbc_al_r10_r0_0x000003fc[] = {
  0x60, 0xf5, 0x7f, 0x7a // sbc al r10 r0 0x000003fc
};
const byte kInstruction_sbc_al_r1_r11_0x2ac00000[] = {
  0x6b, 0xf1, 0x2b, 0x51 // sbc al r1 r11 0x2ac00000
};
const byte kInstruction_sbc_al_r8_r6_0x00156000[] = {
  0x66, 0xf5, 0xab, 0x18 // sbc al r8 r6 0x00156000
};
const byte kInstruction_sbc_al_r7_r12_0x00ff0000[] = {
  0x6c, 0xf5, 0x7f, 0x07 // sbc al r7 r12 0x00ff0000
};
const byte kInstruction_sbc_al_r12_r3_0x00ff0000[] = {
  0x63, 0xf5, 0x7f, 0x0c // sbc al r12 r3 0x00ff0000
};
const byte kInstruction_sbc_al_r4_r7_0x0000ff00[] = {
  0x67, 0xf5, 0x7f, 0x44 // sbc al r4 r7 0x0000ff00
};
const byte kInstruction_sbc_al_r11_r13_0x0ab00000[] = {
  0x6d, 0xf1, 0x2b, 0x6b // sbc al r11 r13 0x0ab00000
};
const byte kInstruction_sbc_al_r6_r12_0xff00ff00[] = {
  0x6c, 0xf1, 0xff, 0x26 // sbc al r6 r12 0xff00ff00
};
const byte kInstruction_sbc_al_r12_r8_0x003fc000[] = {
  0x68, 0xf5, 0x7f, 0x1c // sbc al r12 r8 0x003fc000
};
const byte kInstruction_sbc_al_r5_r12_0x00ab00ab[] = {
  0x6c, 0xf1, 0xab, 0x15 // sbc al r5 r12 0x00ab00ab
};
const byte kInstruction_sbc_al_r7_r6_0x00ab00ab[] = {
  0x66, 0xf1, 0xab, 0x17 // sbc al r7 r6 0x00ab00ab
};
const byte kInstruction_sbc_al_r0_r1_0x00ab00ab[] = {
  0x61, 0xf1, 0xab, 0x10 // sbc al r0 r1 0x00ab00ab
};
const byte kInstruction_sbc_al_r9_r9_0x000001fe[] = {
  0x69, 0xf5, 0xff, 0x79 // sbc al r9 r9 0x000001fe
};
const byte kInstruction_sbc_al_r2_r8_0xab00ab00[] = {
  0x68, 0xf1, 0xab, 0x22 // sbc al r2 r8 0xab00ab00
};
const byte kInstruction_sbc_al_r9_r10_0x00ff0000[] = {
  0x6a, 0xf5, 0x7f, 0x09 // sbc al r9 r10 0x00ff0000
};
const byte kInstruction_sbc_al_r8_r8_0x55800000[] = {
  0x68, 0xf1, 0xab, 0x48 // sbc al r8 r8 0x55800000
};
const byte kInstruction_sbc_al_r6_r7_0x00ab00ab[] = {
  0x67, 0xf1, 0xab, 0x16 // sbc al r6 r7 0x00ab00ab
};
const byte kInstruction_sbc_al_r5_r9_0xff000000[] = {
  0x69, 0xf1, 0x7f, 0x45 // sbc al r5 r9 0xff000000
};
const byte kInstruction_sbc_al_r8_r8_0x00ab0000[] = {
  0x68, 0xf5, 0x2b, 0x08 // sbc al r8 r8 0x00ab0000
};
const byte kInstruction_sbc_al_r5_r8_0xab00ab00[] = {
  0x68, 0xf1, 0xab, 0x25 // sbc al r5 r8 0xab00ab00
};
const byte kInstruction_sbc_al_r0_r12_0xab000000[] = {
  0x6c, 0xf1, 0x2b, 0x40 // sbc al r0 r12 0xab000000
};
const byte kInstruction_sbc_al_r13_r11_0xab000000[] = {
  0x6b, 0xf1, 0x2b, 0x4d // sbc al r13 r11 0xab000000
};
const byte kInstruction_sbc_al_r14_r3_0xab00ab00[] = {
  0x63, 0xf1, 0xab, 0x2e // sbc al r14 r3 0xab00ab00
};
const byte kInstruction_sbc_al_r0_r1_0x0003fc00[] = {
  0x61, 0xf5, 0x7f, 0x30 // sbc al r0 r1 0x0003fc00
};
const byte kInstruction_sbc_al_r14_r13_0x0ab00000[] = {
  0x6d, 0xf1, 0x2b, 0x6e // sbc al r14 r13 0x0ab00000
};
const byte kInstruction_sbc_al_r6_r0_0x0002ac00[] = {
  0x60, 0xf5, 0x2b, 0x36 // sbc al r6 r0 0x0002ac00
};
const byte kInstruction_sbc_al_r6_r8_0x55800000[] = {
  0x68, 0xf1, 0xab, 0x46 // sbc al r6 r8 0x55800000
};
const byte kInstruction_sbc_al_r2_r14_0x01560000[] = {
  0x6e, 0xf1, 0xab, 0x72 // sbc al r2 r14 0x01560000
};
const byte kInstruction_sbc_al_r5_r13_0x03fc0000[] = {
  0x6d, 0xf1, 0x7f, 0x75 // sbc al r5 r13 0x03fc0000
};
const byte kInstruction_sbc_al_r7_r6_0x00000ab0[] = {
  0x66, 0xf5, 0x2b, 0x67 // sbc al r7 r6 0x00000ab0
};
const byte kInstruction_sbc_al_r3_r14_0x007f8000[] = {
  0x6e, 0xf5, 0xff, 0x03 // sbc al r3 r14 0x007f8000
};
const byte kInstruction_sbc_al_r9_r4_0x00558000[] = {
  0x64, 0xf5, 0xab, 0x09 // sbc al r9 r4 0x00558000
};
const byte kInstruction_sbc_al_r10_r11_0x00002ac0[] = {
  0x6b, 0xf5, 0x2b, 0x5a // sbc al r10 r11 0x00002ac0
};
const byte kInstruction_sbc_al_r1_r5_0x003fc000[] = {
  0x65, 0xf5, 0x7f, 0x11 // sbc al r1 r5 0x003fc000
};
const byte kInstruction_sbc_al_r7_r7_0x00003fc0[] = {
  0x67, 0xf5, 0x7f, 0x57 // sbc al r7 r7 0x00003fc0
};
const byte kInstruction_sbc_al_r5_r3_0x000007f8[] = {
  0x63, 0xf5, 0xff, 0x65 // sbc al r5 r3 0x000007f8
};
const byte kInstruction_sbc_al_r4_r3_0x00001560[] = {
  0x63, 0xf5, 0xab, 0x54 // sbc al r4 r3 0x00001560
};
const byte kInstruction_sbc_al_r5_r3_0x03fc0000[] = {
  0x63, 0xf1, 0x7f, 0x75 // sbc al r5 r3 0x03fc0000
};
const byte kInstruction_sbc_al_r2_r6_0x55800000[] = {
  0x66, 0xf1, 0xab, 0x42 // sbc al r2 r6 0x55800000
};
const byte kInstruction_sbc_al_r13_r5_0x0000ab00[] = {
  0x65, 0xf5, 0x2b, 0x4d // sbc al r13 r5 0x0000ab00
};
const byte kInstruction_sbc_al_r0_r11_0xab00ab00[] = {
  0x6b, 0xf1, 0xab, 0x20 // sbc al r0 r11 0xab00ab00
};
const byte kInstruction_sbc_al_r14_r12_0x00ff00ff[] = {
  0x6c, 0xf1, 0xff, 0x1e // sbc al r14 r12 0x00ff00ff
};
const byte kInstruction_sbc_al_r13_r8_0x7f800000[] = {
  0x68, 0xf1, 0xff, 0x4d // sbc al r13 r8 0x7f800000
};
const byte kInstruction_sbc_al_r1_r2_0x15600000[] = {
  0x62, 0xf1, 0xab, 0x51 // sbc al r1 r2 0x15600000
};
const byte kInstruction_sbc_al_r7_r6_0xab000000[] = {
  0x66, 0xf1, 0x2b, 0x47 // sbc al r7 r6 0xab000000
};
const byte kInstruction_sbc_al_r1_r9_0x00000ff0[] = {
  0x69, 0xf5, 0x7f, 0x61 // sbc al r1 r9 0x00000ff0
};
const byte kInstruction_sbc_al_r12_r8_0x0007f800[] = {
  0x68, 0xf5, 0xff, 0x2c // sbc al r12 r8 0x0007f800
};
const byte kInstruction_sbc_al_r0_r8_0x00ab0000[] = {
  0x68, 0xf5, 0x2b, 0x00 // sbc al r0 r8 0x00ab0000
};
const byte kInstruction_sbc_al_r11_r11_0x000000ff[] = {
  0x6b, 0xf1, 0xff, 0x0b // sbc al r11 r11 0x000000ff
};
const byte kInstruction_sbc_al_r12_r13_0xff000000[] = {
  0x6d, 0xf1, 0x7f, 0x4c // sbc al r12 r13 0xff000000
};
const byte kInstruction_sbc_al_r1_r3_0x0ab00000[] = {
  0x63, 0xf1, 0x2b, 0x61 // sbc al r1 r3 0x0ab00000
};
const byte kInstruction_sbc_al_r2_r10_0x0001fe00[] = {
  0x6a, 0xf5, 0xff, 0x32 // sbc al r2 r10 0x0001fe00
};
const byte kInstruction_sbc_al_r14_r2_0x01fe0000[] = {
  0x62, 0xf1, 0xff, 0x7e // sbc al r14 r2 0x01fe0000
};
const byte kInstruction_sbc_al_r3_r4_0x000000ff[] = {
  0x64, 0xf1, 0xff, 0x03 // sbc al r3 r4 0x000000ff
};
const byte kInstruction_sbc_al_r3_r13_0x00000558[] = {
  0x6d, 0xf5, 0xab, 0x63 // sbc al r3 r13 0x00000558
};
const byte kInstruction_sbc_al_r13_r10_0x00055800[] = {
  0x6a, 0xf5, 0xab, 0x2d // sbc al r13 r10 0x00055800
};
const byte kInstruction_sbc_al_r1_r10_0xff000000[] = {
  0x6a, 0xf1, 0x7f, 0x41 // sbc al r1 r10 0xff000000
};
const byte kInstruction_sbc_al_r0_r7_0x2ac00000[] = {
  0x67, 0xf1, 0x2b, 0x50 // sbc al r0 r7 0x2ac00000
};
const byte kInstruction_sbc_al_r12_r1_0xab000000[] = {
  0x61, 0xf1, 0x2b, 0x4c // sbc al r12 r1 0xab000000
};
const byte kInstruction_sbc_al_r9_r14_0x00003fc0[] = {
  0x6e, 0xf5, 0x7f, 0x59 // sbc al r9 r14 0x00003fc0
};
const byte kInstruction_sbc_al_r7_r2_0x2ac00000[] = {
  0x62, 0xf1, 0x2b, 0x57 // sbc al r7 r2 0x2ac00000
};
const byte kInstruction_sbc_al_r14_r4_0x00001fe0[] = {
  0x64, 0xf5, 0xff, 0x5e // sbc al r14 r4 0x00001fe0
};
const byte kInstruction_sbc_al_r12_r8_0x00007f80[] = {
  0x68, 0xf5, 0xff, 0x4c // sbc al r12 r8 0x00007f80
};
const byte kInstruction_sbc_al_r7_r10_0x00000ab0[] = {
  0x6a, 0xf5, 0x2b, 0x67 // sbc al r7 r10 0x00000ab0
};
const byte kInstruction_sbc_al_r13_r6_0x00ab0000[] = {
  0x66, 0xf5, 0x2b, 0x0d // sbc al r13 r6 0x00ab0000
};
const byte kInstruction_sbc_al_r7_r9_0x0000ff00[] = {
  0x69, 0xf5, 0x7f, 0x47 // sbc al r7 r9 0x0000ff00
};
const byte kInstruction_sbc_al_r2_r12_0xff00ff00[] = {
  0x6c, 0xf1, 0xff, 0x22 // sbc al r2 r12 0xff00ff00
};
const byte kInstruction_sbc_al_r1_r6_0x00000156[] = {
  0x66, 0xf5, 0xab, 0x71 // sbc al r1 r6 0x00000156
};
const byte kInstruction_sbc_al_r7_r5_0x03fc0000[] = {
  0x65, 0xf1, 0x7f, 0x77 // sbc al r7 r5 0x03fc0000
};
const byte kInstruction_sbc_al_r2_r9_0x01fe0000[] = {
  0x69, 0xf1, 0xff, 0x72 // sbc al r2 r9 0x01fe0000
};
const byte kInstruction_sbc_al_r10_r12_0x00002ac0[] = {
  0x6c, 0xf5, 0x2b, 0x5a // sbc al r10 r12 0x00002ac0
};
const byte kInstruction_sbc_al_r14_r10_0x7f800000[] = {
  0x6a, 0xf1, 0xff, 0x4e // sbc al r14 r10 0x7f800000
};
const byte kInstruction_sbc_al_r2_r8_0x02ac0000[] = {
  0x68, 0xf1, 0x2b, 0x72 // sbc al r2 r8 0x02ac0000
};
const byte kInstruction_sbc_al_r4_r9_0x000001fe[] = {
  0x69, 0xf5, 0xff, 0x74 // sbc al r4 r9 0x000001fe
};
const byte kInstruction_sbc_al_r10_r10_0x000001fe[] = {
  0x6a, 0xf5, 0xff, 0x7a // sbc al r10 r10 0x000001fe
};
const byte kInstruction_sbc_al_r6_r6_0x3fc00000[] = {
  0x66, 0xf1, 0x7f, 0x56 // sbc al r6 r6 0x3fc00000
};
const byte kInstruction_sbc_al_r4_r12_0x000003fc[] = {
  0x6c, 0xf5, 0x7f, 0x74 // sbc al r4 r12 0x000003fc
};
const byte kInstruction_sbc_al_r0_r2_0x0000ff00[] = {
  0x62, 0xf5, 0x7f, 0x40 // sbc al r0 r2 0x0000ff00
};
const byte kInstruction_sbc_al_r9_r0_0x003fc000[] = {
  0x60, 0xf5, 0x7f, 0x19 // sbc al r9 r0 0x003fc000
};
const byte kInstruction_sbc_al_r7_r4_0x000002ac[] = {
  0x64, 0xf5, 0x2b, 0x77 // sbc al r7 r4 0x000002ac
};
const byte kInstruction_sbc_al_r6_r6_0x7f800000[] = {
  0x66, 0xf1, 0xff, 0x46 // sbc al r6 r6 0x7f800000
};
const byte kInstruction_sbc_al_r6_r8_0x00015600[] = {
  0x68, 0xf5, 0xab, 0x36 // sbc al r6 r8 0x00015600
};
const byte kInstruction_sbc_al_r10_r0_0x00000ff0[] = {
  0x60, 0xf5, 0x7f, 0x6a // sbc al r10 r0 0x00000ff0
};
const byte kInstruction_sbc_al_r8_r1_0xffffffff[] = {
  0x61, 0xf1, 0xff, 0x38 // sbc al r8 r1 0xffffffff
};
const byte kInstruction_sbc_al_r3_r7_0x00ab00ab[] = {
  0x67, 0xf1, 0xab, 0x13 // sbc al r3 r7 0x00ab00ab
};
const byte kInstruction_sbc_al_r8_r11_0x01fe0000[] = {
  0x6b, 0xf1, 0xff, 0x78 // sbc al r8 r11 0x01fe0000
};
const byte kInstruction_sbc_al_r3_r1_0x00ff0000[] = {
  0x61, 0xf5, 0x7f, 0x03 // sbc al r3 r1 0x00ff0000
};
const byte kInstruction_sbc_al_r5_r4_0x000001fe[] = {
  0x64, 0xf5, 0xff, 0x75 // sbc al r5 r4 0x000001fe
};
const byte kInstruction_sbc_al_r7_r10_0x00000558[] = {
  0x6a, 0xf5, 0xab, 0x67 // sbc al r7 r10 0x00000558
};
const byte kInstruction_sbc_al_r8_r13_0x00001560[] = {
  0x6d, 0xf5, 0xab, 0x58 // sbc al r8 r13 0x00001560
};
const byte kInstruction_sbc_al_r9_r4_0x00002ac0[] = {
  0x64, 0xf5, 0x2b, 0x59 // sbc al r9 r4 0x00002ac0
};
const byte kInstruction_sbc_al_r9_r7_0x03fc0000[] = {
  0x67, 0xf1, 0x7f, 0x79 // sbc al r9 r7 0x03fc0000
};
const byte kInstruction_sbc_al_r11_r12_0x2ac00000[] = {
  0x6c, 0xf1, 0x2b, 0x5b // sbc al r11 r12 0x2ac00000
};
const byte kInstruction_sbc_al_r13_r10_0x00001fe0[] = {
  0x6a, 0xf5, 0xff, 0x5d // sbc al r13 r10 0x00001fe0
};
const byte kInstruction_sbc_al_r11_r10_0x00558000[] = {
  0x6a, 0xf5, 0xab, 0x0b // sbc al r11 r10 0x00558000
};
const byte kInstruction_sbc_al_r3_r2_0x000000ab[] = {
  0x62, 0xf1, 0xab, 0x03 // sbc al r3 r2 0x000000ab
};
const byte kInstruction_sbc_al_r0_r8_0x00000ab0[] = {
  0x68, 0xf5, 0x2b, 0x60 // sbc al r0 r8 0x00000ab0
};
const byte kInstruction_sbc_al_r9_r7_0xab000000[] = {
  0x67, 0xf1, 0x2b, 0x49 // sbc al r9 r7 0xab000000
};
const byte kInstruction_sbc_al_r11_r7_0x0ff00000[] = {
  0x67, 0xf1, 0x7f, 0x6b // sbc al r11 r7 0x0ff00000
};
const byte kInstruction_sbc_al_r10_r2_0x7f800000[] = {
  0x62, 0xf1, 0xff, 0x4a // sbc al r10 r2 0x7f800000
};
const byte kInstruction_sbc_al_r3_r1_0x05580000[] = {
  0x61, 0xf1, 0xab, 0x63 // sbc al r3 r1 0x05580000
};
const byte kInstruction_sbc_al_r1_r4_0x0ab00000[] = {
  0x64, 0xf1, 0x2b, 0x61 // sbc al r1 r4 0x0ab00000
};
const byte kInstruction_sbc_al_r4_r9_0x00005580[] = {
  0x69, 0xf5, 0xab, 0x44 // sbc al r4 r9 0x00005580
};
const byte kInstruction_sbc_al_r3_r2_0x001fe000[] = {
  0x62, 0xf5, 0xff, 0x13 // sbc al r3 r2 0x001fe000
};
const byte kInstruction_sbc_al_r14_r6_0x00000156[] = {
  0x66, 0xf5, 0xab, 0x7e // sbc al r14 r6 0x00000156
};
const byte kInstruction_sbc_al_r14_r3_0x00000ab0[] = {
  0x63, 0xf5, 0x2b, 0x6e // sbc al r14 r3 0x00000ab0
};
const byte kInstruction_sbc_al_r12_r13_0x000001fe[] = {
  0x6d, 0xf5, 0xff, 0x7c // sbc al r12 r13 0x000001fe
};
const byte kInstruction_sbc_al_r12_r10_0x1fe00000[] = {
  0x6a, 0xf1, 0xff, 0x5c // sbc al r12 r10 0x1fe00000
};
const byte kInstruction_sbc_al_r0_r9_0x2ac00000[] = {
  0x69, 0xf1, 0x2b, 0x50 // sbc al r0 r9 0x2ac00000
};
const byte kInstruction_sbc_al_r11_r6_0x00000156[] = {
  0x66, 0xf5, 0xab, 0x7b // sbc al r11 r6 0x00000156
};
const byte kInstruction_sbc_al_r2_r4_0x3fc00000[] = {
  0x64, 0xf1, 0x7f, 0x52 // sbc al r2 r4 0x3fc00000
};
const byte kInstruction_sbc_al_r8_r13_0x00002ac0[] = {
  0x6d, 0xf5, 0x2b, 0x58 // sbc al r8 r13 0x00002ac0
};
const byte kInstruction_sbc_al_r1_r5_0x00ff00ff[] = {
  0x65, 0xf1, 0xff, 0x11 // sbc al r1 r5 0x00ff00ff
};
const byte kInstruction_sbc_al_r6_r1_0x0007f800[] = {
  0x61, 0xf5, 0xff, 0x26 // sbc al r6 r1 0x0007f800
};
const byte kInstruction_sbc_al_r5_r1_0x00001fe0[] = {
  0x61, 0xf5, 0xff, 0x55 // sbc al r5 r1 0x00001fe0
};
const byte kInstruction_sbc_al_r8_r11_0xab00ab00[] = {
  0x6b, 0xf1, 0xab, 0x28 // sbc al r8 r11 0xab00ab00
};
const byte kInstruction_sbc_al_r5_r0_0xff00ff00[] = {
  0x60, 0xf1, 0xff, 0x25 // sbc al r5 r0 0xff00ff00
};
const byte kInstruction_sbc_al_r14_r13_0x000000ab[] = {
  0x6d, 0xf1, 0xab, 0x0e // sbc al r14 r13 0x000000ab
};
const byte kInstruction_sbc_al_r2_r4_0x05580000[] = {
  0x64, 0xf1, 0xab, 0x62 // sbc al r2 r4 0x05580000
};
const byte kInstruction_sbc_al_r14_r10_0x07f80000[] = {
  0x6a, 0xf1, 0xff, 0x6e // sbc al r14 r10 0x07f80000
};
const byte kInstruction_sbc_al_r10_r3_0x55800000[] = {
  0x63, 0xf1, 0xab, 0x4a // sbc al r10 r3 0x55800000
};
const byte kInstruction_sbc_al_r0_r11_0x7f800000[] = {
  0x6b, 0xf1, 0xff, 0x40 // sbc al r0 r11 0x7f800000
};
const byte kInstruction_sbc_al_r3_r12_0xffffffff[] = {
  0x6c, 0xf1, 0xff, 0x33 // sbc al r3 r12 0xffffffff
};
const byte kInstruction_sbc_al_r2_r3_0x00000558[] = {
  0x63, 0xf5, 0xab, 0x62 // sbc al r2 r3 0x00000558
};
const byte kInstruction_sbc_al_r2_r2_0x0003fc00[] = {
  0x62, 0xf5, 0x7f, 0x32 // sbc al r2 r2 0x0003fc00
};
const byte kInstruction_sbc_al_r14_r10_0x15600000[] = {
  0x6a, 0xf1, 0xab, 0x5e // sbc al r14 r10 0x15600000
};
const byte kInstruction_sbc_al_r3_r13_0x00000156[] = {
  0x6d, 0xf5, 0xab, 0x73 // sbc al r3 r13 0x00000156
};
const byte kInstruction_sbc_al_r10_r5_0x1fe00000[] = {
  0x65, 0xf1, 0xff, 0x5a // sbc al r10 r5 0x1fe00000
};
const byte kInstruction_sbc_al_r1_r5_0x00055800[] = {
  0x65, 0xf5, 0xab, 0x21 // sbc al r1 r5 0x00055800
};
const byte kInstruction_sbc_al_r8_r6_0xff000000[] = {
  0x66, 0xf1, 0x7f, 0x48 // sbc al r8 r6 0xff000000
};
const byte kInstruction_sbc_al_r3_r7_0x002ac000[] = {
  0x67, 0xf5, 0x2b, 0x13 // sbc al r3 r7 0x002ac000
};
const byte kInstruction_sbc_al_r6_r4_0x00ff00ff[] = {
  0x64, 0xf1, 0xff, 0x16 // sbc al r6 r4 0x00ff00ff
};
const byte kInstruction_sbc_al_r0_r8_0x0007f800[] = {
  0x68, 0xf5, 0xff, 0x20 // sbc al r0 r8 0x0007f800
};
const byte kInstruction_sbc_al_r0_r3_0xff000000[] = {
  0x63, 0xf1, 0x7f, 0x40 // sbc al r0 r3 0xff000000
};
const byte kInstruction_sbc_al_r11_r1_0xabababab[] = {
  0x61, 0xf1, 0xab, 0x3b // sbc al r11 r1 0xabababab
};
const byte kInstruction_sbc_al_r14_r10_0x000001fe[] = {
  0x6a, 0xf5, 0xff, 0x7e // sbc al r14 r10 0x000001fe
};
const byte kInstruction_sbc_al_r4_r11_0x002ac000[] = {
  0x6b, 0xf5, 0x2b, 0x14 // sbc al r4 r11 0x002ac000
};
const byte kInstruction_sbc_al_r11_r12_0x000000ab[] = {
  0x6c, 0xf1, 0xab, 0x0b // sbc al r11 r12 0x000000ab
};
const byte kInstruction_sbc_al_r3_r4_0x003fc000[] = {
  0x64, 0xf5, 0x7f, 0x13 // sbc al r3 r4 0x003fc000
};
const byte kInstruction_sbc_al_r3_r13_0x0ff00000[] = {
  0x6d, 0xf1, 0x7f, 0x63 // sbc al r3 r13 0x0ff00000
};
const byte kInstruction_sbc_al_r5_r4_0x00001fe0[] = {
  0x64, 0xf5, 0xff, 0x55 // sbc al r5 r4 0x00001fe0
};
const byte kInstruction_sbc_al_r6_r12_0x002ac000[] = {
  0x6c, 0xf5, 0x2b, 0x16 // sbc al r6 r12 0x002ac000
};
const byte kInstruction_sbc_al_r13_r13_0x1fe00000[] = {
  0x6d, 0xf1, 0xff, 0x5d // sbc al r13 r13 0x1fe00000
};
const byte kInstruction_sbc_al_r0_r8_0x01560000[] = {
  0x68, 0xf1, 0xab, 0x70 // sbc al r0 r8 0x01560000
};
const byte kInstruction_sbc_al_r9_r7_0x00055800[] = {
  0x67, 0xf5, 0xab, 0x29 // sbc al r9 r7 0x00055800
};
const byte kInstruction_sbc_al_r6_r0_0x00000156[] = {
  0x60, 0xf5, 0xab, 0x76 // sbc al r6 r0 0x00000156
};
const byte kInstruction_sbc_al_r14_r12_0x00055800[] = {
  0x6c, 0xf5, 0xab, 0x2e // sbc al r14 r12 0x00055800
};
const byte kInstruction_sbc_al_r14_r0_0xab00ab00[] = {
  0x60, 0xf1, 0xab, 0x2e // sbc al r14 r0 0xab00ab00
};
const byte kInstruction_sbc_al_r14_r2_0x00ab0000[] = {
  0x62, 0xf5, 0x2b, 0x0e // sbc al r14 r2 0x00ab0000
};
const byte kInstruction_sbc_al_r0_r3_0x000000ab[] = {
  0x63, 0xf1, 0xab, 0x00 // sbc al r0 r3 0x000000ab
};
const byte kInstruction_sbc_al_r13_r4_0x003fc000[] = {
  0x64, 0xf5, 0x7f, 0x1d // sbc al r13 r4 0x003fc000
};
const byte kInstruction_sbc_al_r4_r2_0x00001560[] = {
  0x62, 0xf5, 0xab, 0x54 // sbc al r4 r2 0x00001560
};
const byte kInstruction_sbc_al_r14_r4_0x2ac00000[] = {
  0x64, 0xf1, 0x2b, 0x5e // sbc al r14 r4 0x2ac00000
};
const byte kInstruction_sbc_al_r4_r11_0x000003fc[] = {
  0x6b, 0xf5, 0x7f, 0x74 // sbc al r4 r11 0x000003fc
};
const byte kInstruction_sbc_al_r6_r8_0x001fe000[] = {
  0x68, 0xf5, 0xff, 0x16 // sbc al r6 r8 0x001fe000
};
const byte kInstruction_sbc_al_r12_r14_0x00000558[] = {
  0x6e, 0xf5, 0xab, 0x6c // sbc al r12 r14 0x00000558
};
const byte kInstruction_sbc_al_r0_r13_0x0ff00000[] = {
  0x6d, 0xf1, 0x7f, 0x60 // sbc al r0 r13 0x0ff00000
};
const byte kInstruction_sbc_al_r3_r11_0xabababab[] = {
  0x6b, 0xf1, 0xab, 0x33 // sbc al r3 r11 0xabababab
};
const byte kInstruction_sbc_al_r4_r1_0x000001fe[] = {
  0x61, 0xf5, 0xff, 0x74 // sbc al r4 r1 0x000001fe
};
const byte kInstruction_sbc_al_r0_r5_0x000002ac[] = {
  0x65, 0xf5, 0x2b, 0x70 // sbc al r0 r5 0x000002ac
};
const byte kInstruction_sbc_al_r8_r5_0x0003fc00[] = {
  0x65, 0xf5, 0x7f, 0x38 // sbc al r8 r5 0x0003fc00
};
const byte kInstruction_sbc_al_r7_r13_0x0002ac00[] = {
  0x6d, 0xf5, 0x2b, 0x37 // sbc al r7 r13 0x0002ac00
};
const byte kInstruction_sbc_al_r10_r6_0x00015600[] = {
  0x66, 0xf5, 0xab, 0x3a // sbc al r10 r6 0x00015600
};
const byte kInstruction_sbc_al_r12_r10_0x00ff0000[] = {
  0x6a, 0xf5, 0x7f, 0x0c // sbc al r12 r10 0x00ff0000
};
const byte kInstruction_sbc_al_r12_r12_0x00005580[] = {
  0x6c, 0xf5, 0xab, 0x4c // sbc al r12 r12 0x00005580
};
const byte kInstruction_sbc_al_r0_r4_0x02ac0000[] = {
  0x64, 0xf1, 0x2b, 0x70 // sbc al r0 r4 0x02ac0000
};
const byte kInstruction_sbc_al_r9_r9_0x02ac0000[] = {
  0x69, 0xf1, 0x2b, 0x79 // sbc al r9 r9 0x02ac0000
};
const byte kInstruction_sbc_al_r7_r4_0x00000558[] = {
  0x64, 0xf5, 0xab, 0x67 // sbc al r7 r4 0x00000558
};
const byte kInstruction_sbc_al_r12_r14_0x07f80000[] = {
  0x6e, 0xf1, 0xff, 0x6c // sbc al r12 r14 0x07f80000
};
const byte kInstruction_sbc_al_r7_r2_0xab00ab00[] = {
  0x62, 0xf1, 0xab, 0x27 // sbc al r7 r2 0xab00ab00
};
const byte kInstruction_sbc_al_r1_r12_0xff000000[] = {
  0x6c, 0xf1, 0x7f, 0x41 // sbc al r1 r12 0xff000000
};
const byte kInstruction_sbc_al_r8_r0_0x7f800000[] = {
  0x60, 0xf1, 0xff, 0x48 // sbc al r8 r0 0x7f800000
};
const byte kInstruction_sbc_al_r7_r0_0x00000ab0[] = {
  0x60, 0xf5, 0x2b, 0x67 // sbc al r7 r0 0x00000ab0
};
const byte kInstruction_sbc_al_r1_r0_0x00005580[] = {
  0x60, 0xf5, 0xab, 0x41 // sbc al r1 r0 0x00005580
};
const byte kInstruction_sbc_al_r14_r1_0x001fe000[] = {
  0x61, 0xf5, 0xff, 0x1e // sbc al r14 r1 0x001fe000
};
const byte kInstruction_sbc_al_r13_r13_0x0002ac00[] = {
  0x6d, 0xf5, 0x2b, 0x3d // sbc al r13 r13 0x0002ac00
};
const byte kInstruction_sbc_al_r8_r12_0x0002ac00[] = {
  0x6c, 0xf5, 0x2b, 0x38 // sbc al r8 r12 0x0002ac00
};
const byte kInstruction_sbc_al_r10_r10_0x00ff00ff[] = {
  0x6a, 0xf1, 0xff, 0x1a // sbc al r10 r10 0x00ff00ff
};
const byte kInstruction_sbc_al_r4_r4_0x002ac000[] = {
  0x64, 0xf5, 0x2b, 0x14 // sbc al r4 r4 0x002ac000
};
const byte kInstruction_sbc_al_r12_r5_0x000ab000[] = {
  0x65, 0xf5, 0x2b, 0x2c // sbc al r12 r5 0x000ab000
};
const byte kInstruction_sbc_al_r1_r2_0x000003fc[] = {
  0x62, 0xf5, 0x7f, 0x71 // sbc al r1 r2 0x000003fc
};
const byte kInstruction_sbc_al_r10_r11_0x001fe000[] = {
  0x6b, 0xf5, 0xff, 0x1a // sbc al r10 r11 0x001fe000
};
const byte kInstruction_sbc_al_r11_r2_0x05580000[] = {
  0x62, 0xf1, 0xab, 0x6b // sbc al r11 r2 0x05580000
};
const byte kInstruction_sbc_al_r2_r6_0x000000ab[] = {
  0x66, 0xf1, 0xab, 0x02 // sbc al r2 r6 0x000000ab
};
const byte kInstruction_sbc_al_r6_r3_0x0000ff00[] = {
  0x63, 0xf5, 0x7f, 0x46 // sbc al r6 r3 0x0000ff00
};
const byte kInstruction_sbc_al_r13_r0_0x00156000[] = {
  0x60, 0xf5, 0xab, 0x1d // sbc al r13 r0 0x00156000
};
const byte kInstruction_sbc_al_r2_r9_0x00002ac0[] = {
  0x69, 0xf5, 0x2b, 0x52 // sbc al r2 r9 0x00002ac0
};
const byte kInstruction_sbc_al_r11_r7_0x00055800[] = {
  0x67, 0xf5, 0xab, 0x2b // sbc al r11 r7 0x00055800
};
const byte kInstruction_sbc_al_r10_r9_0x00001fe0[] = {
  0x69, 0xf5, 0xff, 0x5a // sbc al r10 r9 0x00001fe0
};
const byte kInstruction_sbc_al_r10_r11_0x00156000[] = {
  0x6b, 0xf5, 0xab, 0x1a // sbc al r10 r11 0x00156000
};
const byte kInstruction_sbc_al_r12_r10_0xff00ff00[] = {
  0x6a, 0xf1, 0xff, 0x2c // sbc al r12 r10 0xff00ff00
};
const byte kInstruction_sbc_al_r7_r14_0x00ab00ab[] = {
  0x6e, 0xf1, 0xab, 0x17 // sbc al r7 r14 0x00ab00ab
};
const byte kInstruction_sbc_al_r14_r7_0x002ac000[] = {
  0x67, 0xf5, 0x2b, 0x1e // sbc al r14 r7 0x002ac000
};
const byte kInstruction_sbc_al_r5_r6_0x000ff000[] = {
  0x66, 0xf5, 0x7f, 0x25 // sbc al r5 r6 0x000ff000
};
const byte kInstruction_sbc_al_r8_r1_0xff000000[] = {
  0x61, 0xf1, 0x7f, 0x48 // sbc al r8 r1 0xff000000
};
const byte kInstruction_sbc_al_r8_r0_0x000002ac[] = {
  0x60, 0xf5, 0x2b, 0x78 // sbc al r8 r0 0x000002ac
};
const byte kInstruction_sbc_al_r12_r6_0x00002ac0[] = {
  0x66, 0xf5, 0x2b, 0x5c // sbc al r12 r6 0x00002ac0
};
const byte kInstruction_sbc_al_r14_r2_0x3fc00000[] = {
  0x62, 0xf1, 0x7f, 0x5e // sbc al r14 r2 0x3fc00000
};
const byte kInstruction_sbc_al_r3_r3_0x01560000[] = {
  0x63, 0xf1, 0xab, 0x73 // sbc al r3 r3 0x01560000
};
const byte kInstruction_sbc_al_r3_r12_0x0001fe00[] = {
  0x6c, 0xf5, 0xff, 0x33 // sbc al r3 r12 0x0001fe00
};
const byte kInstruction_sbc_al_r8_r10_0x000002ac[] = {
  0x6a, 0xf5, 0x2b, 0x78 // sbc al r8 r10 0x000002ac
};
const byte kInstruction_sbc_al_r9_r9_0x002ac000[] = {
  0x69, 0xf5, 0x2b, 0x19 // sbc al r9 r9 0x002ac000
};
const byte kInstruction_sbc_al_r0_r6_0x00156000[] = {
  0x66, 0xf5, 0xab, 0x10 // sbc al r0 r6 0x00156000
};
const byte kInstruction_sbc_al_r14_r7_0x0ff00000[] = {
  0x67, 0xf1, 0x7f, 0x6e // sbc al r14 r7 0x0ff00000
};
const byte kInstruction_sbc_al_r1_r3_0x00005580[] = {
  0x63, 0xf5, 0xab, 0x41 // sbc al r1 r3 0x00005580
};
const byte kInstruction_sbc_al_r14_r7_0x000001fe[] = {
  0x67, 0xf5, 0xff, 0x7e // sbc al r14 r7 0x000001fe
};
const byte kInstruction_sbc_al_r9_r5_0x03fc0000[] = {
  0x65, 0xf1, 0x7f, 0x79 // sbc al r9 r5 0x03fc0000
};
const byte kInstruction_sbc_al_r7_r14_0x002ac000[] = {
  0x6e, 0xf5, 0x2b, 0x17 // sbc al r7 r14 0x002ac000
};
const byte kInstruction_sbc_al_r8_r9_0x00000558[] = {
  0x69, 0xf5, 0xab, 0x68 // sbc al r8 r9 0x00000558
};
const byte kInstruction_sbc_al_r14_r1_0x007f8000[] = {
  0x61, 0xf5, 0xff, 0x0e // sbc al r14 r1 0x007f8000
};
const byte kInstruction_sbc_al_r11_r0_0xab00ab00[] = {
  0x60, 0xf1, 0xab, 0x2b // sbc al r11 r0 0xab00ab00
};
const byte kInstruction_sbc_al_r11_r8_0x00000156[] = {
  0x68, 0xf5, 0xab, 0x7b // sbc al r11 r8 0x00000156
};
const byte kInstruction_sbc_al_r4_r10_0x00055800[] = {
  0x6a, 0xf5, 0xab, 0x24 // sbc al r4 r10 0x00055800
};
const byte kInstruction_sbc_al_r2_r7_0x00007f80[] = {
  0x67, 0xf5, 0xff, 0x42 // sbc al r2 r7 0x00007f80
};
const byte kInstruction_sbc_al_r0_r6_0x00558000[] = {
  0x66, 0xf5, 0xab, 0x00 // sbc al r0 r6 0x00558000
};
const byte kInstruction_sbc_al_r4_r2_0x00558000[] = {
  0x62, 0xf5, 0xab, 0x04 // sbc al r4 r2 0x00558000
};
const byte kInstruction_sbc_al_r2_r3_0x0007f800[] = {
  0x63, 0xf5, 0xff, 0x22 // sbc al r2 r3 0x0007f800
};
const byte kInstruction_sbc_al_r14_r14_0xab00ab00[] = {
  0x6e, 0xf1, 0xab, 0x2e // sbc al r14 r14 0xab00ab00
};
const byte kInstruction_sbc_al_r0_r13_0x000000ff[] = {
  0x6d, 0xf1, 0xff, 0x00 // sbc al r0 r13 0x000000ff
};
const byte kInstruction_sbc_al_r10_r9_0xab00ab00[] = {
  0x69, 0xf1, 0xab, 0x2a // sbc al r10 r9 0xab00ab00
};
const byte kInstruction_sbc_al_r1_r1_0x3fc00000[] = {
  0x61, 0xf1, 0x7f, 0x51 // sbc al r1 r1 0x3fc00000
};
const byte kInstruction_sbc_al_r8_r6_0x002ac000[] = {
  0x66, 0xf5, 0x2b, 0x18 // sbc al r8 r6 0x002ac000
};
const byte kInstruction_sbc_al_r12_r4_0x55800000[] = {
  0x64, 0xf1, 0xab, 0x4c // sbc al r12 r4 0x55800000
};
const byte kInstruction_sbc_al_r6_r10_0x2ac00000[] = {
  0x6a, 0xf1, 0x2b, 0x56 // sbc al r6 r10 0x2ac00000
};
const byte kInstruction_sbc_al_r7_r9_0x001fe000[] = {
  0x69, 0xf5, 0xff, 0x17 // sbc al r7 r9 0x001fe000
};
const byte kInstruction_sbc_al_r4_r12_0x00005580[] = {
  0x6c, 0xf5, 0xab, 0x44 // sbc al r4 r12 0x00005580
};
const byte kInstruction_sbc_al_r9_r8_0x0ab00000[] = {
  0x68, 0xf1, 0x2b, 0x69 // sbc al r9 r8 0x0ab00000
};
const byte kInstruction_sbc_al_r2_r4_0xff00ff00[] = {
  0x64, 0xf1, 0xff, 0x22 // sbc al r2 r4 0xff00ff00
};
const byte kInstruction_sbc_al_r8_r14_0x00001fe0[] = {
  0x6e, 0xf5, 0xff, 0x58 // sbc al r8 r14 0x00001fe0
};
const byte kInstruction_sbc_al_r5_r3_0x003fc000[] = {
  0x63, 0xf5, 0x7f, 0x15 // sbc al r5 r3 0x003fc000
};
const byte kInstruction_sbc_al_r2_r10_0x00ff00ff[] = {
  0x6a, 0xf1, 0xff, 0x12 // sbc al r2 r10 0x00ff00ff
};
const byte kInstruction_sbc_al_r11_r12_0x15600000[] = {
  0x6c, 0xf1, 0xab, 0x5b // sbc al r11 r12 0x15600000
};
const byte kInstruction_sbc_al_r1_r5_0x00002ac0[] = {
  0x65, 0xf5, 0x2b, 0x51 // sbc al r1 r5 0x00002ac0
};
const byte kInstruction_sbc_al_r3_r7_0x2ac00000[] = {
  0x67, 0xf1, 0x2b, 0x53 // sbc al r3 r7 0x2ac00000
};
const byte kInstruction_sbc_al_r5_r1_0xffffffff[] = {
  0x61, 0xf1, 0xff, 0x35 // sbc al r5 r1 0xffffffff
};
const byte kInstruction_sbc_al_r4_r10_0xff00ff00[] = {
  0x6a, 0xf1, 0xff, 0x24 // sbc al r4 r10 0xff00ff00
};
const byte kInstruction_sbc_al_r1_r2_0x00001fe0[] = {
  0x62, 0xf5, 0xff, 0x51 // sbc al r1 r2 0x00001fe0
};
const byte kInstruction_sbc_al_r5_r14_0x000000ff[] = {
  0x6e, 0xf1, 0xff, 0x05 // sbc al r5 r14 0x000000ff
};
const byte kInstruction_sbc_al_r14_r0_0x000ab000[] = {
  0x60, 0xf5, 0x2b, 0x2e // sbc al r14 r0 0x000ab000
};
const byte kInstruction_sbc_al_r10_r3_0x00ab0000[] = {
  0x63, 0xf5, 0x2b, 0x0a // sbc al r10 r3 0x00ab0000
};
const byte kInstruction_sbc_al_r10_r12_0x03fc0000[] = {
  0x6c, 0xf1, 0x7f, 0x7a // sbc al r10 r12 0x03fc0000
};
const byte kInstruction_sbc_al_r8_r11_0x0007f800[] = {
  0x6b, 0xf5, 0xff, 0x28 // sbc al r8 r11 0x0007f800
};
const byte kInstruction_sbc_al_r9_r13_0x0001fe00[] = {
  0x6d, 0xf5, 0xff, 0x39 // sbc al r9 r13 0x0001fe00
};
const byte kInstruction_sbc_al_r12_r13_0x02ac0000[] = {
  0x6d, 0xf1, 0x2b, 0x7c // sbc al r12 r13 0x02ac0000
};
const byte kInstruction_sbc_al_r3_r9_0x00ab00ab[] = {
  0x69, 0xf1, 0xab, 0x13 // sbc al r3 r9 0x00ab00ab
};
const byte kInstruction_sbc_al_r10_r1_0x3fc00000[] = {
  0x61, 0xf1, 0x7f, 0x5a // sbc al r10 r1 0x3fc00000
};
const byte kInstruction_sbc_al_r6_r8_0x00000558[] = {
  0x68, 0xf5, 0xab, 0x66 // sbc al r6 r8 0x00000558
};
const byte kInstruction_sbc_al_r6_r12_0x0000ab00[] = {
  0x6c, 0xf5, 0x2b, 0x46 // sbc al r6 r12 0x0000ab00
};
const byte kInstruction_sbc_al_r14_r13_0x000ab000[] = {
  0x6d, 0xf5, 0x2b, 0x2e // sbc al r14 r13 0x000ab000
};
const byte kInstruction_sbc_al_r1_r5_0x1fe00000[] = {
  0x65, 0xf1, 0xff, 0x51 // sbc al r1 r5 0x1fe00000
};
const byte kInstruction_sbc_al_r11_r3_0x02ac0000[] = {
  0x63, 0xf1, 0x2b, 0x7b // sbc al r11 r3 0x02ac0000
};
const byte kInstruction_sbc_al_r9_r5_0x55800000[] = {
  0x65, 0xf1, 0xab, 0x49 // sbc al r9 r5 0x55800000
};
const byte kInstruction_sbc_al_r5_r5_0x000ab000[] = {
  0x65, 0xf5, 0x2b, 0x25 // sbc al r5 r5 0x000ab000
};
const byte kInstruction_sbc_al_r0_r12_0x003fc000[] = {
  0x6c, 0xf5, 0x7f, 0x10 // sbc al r0 r12 0x003fc000
};
const byte kInstruction_sbc_al_r10_r4_0x0000ab00[] = {
  0x64, 0xf5, 0x2b, 0x4a // sbc al r10 r4 0x0000ab00
};
const byte kInstruction_sbc_al_r3_r2_0x0000ff00[] = {
  0x62, 0xf5, 0x7f, 0x43 // sbc al r3 r2 0x0000ff00
};
const byte kInstruction_sbc_al_r14_r8_0x3fc00000[] = {
  0x68, 0xf1, 0x7f, 0x5e // sbc al r14 r8 0x3fc00000
};
const byte kInstruction_sbc_al_r10_r13_0x05580000[] = {
  0x6d, 0xf1, 0xab, 0x6a // sbc al r10 r13 0x05580000
};
const byte kInstruction_sbc_al_r4_r13_0x00156000[] = {
  0x6d, 0xf5, 0xab, 0x14 // sbc al r4 r13 0x00156000
};
const byte kInstruction_sbc_al_r7_r2_0x000002ac[] = {
  0x62, 0xf5, 0x2b, 0x77 // sbc al r7 r2 0x000002ac
};
const byte kInstruction_sbc_al_r5_r10_0x000002ac[] = {
  0x6a, 0xf5, 0x2b, 0x75 // sbc al r5 r10 0x000002ac
};
const byte kInstruction_sbc_al_r7_r0_0xab000000[] = {
  0x60, 0xf1, 0x2b, 0x47 // sbc al r7 r0 0xab000000
};
const byte kInstruction_sbc_al_r1_r10_0x000002ac[] = {
  0x6a, 0xf5, 0x2b, 0x71 // sbc al r1 r10 0x000002ac
};
const byte kInstruction_sbc_al_r11_r9_0x00002ac0[] = {
  0x69, 0xf5, 0x2b, 0x5b // sbc al r11 r9 0x00002ac0
};
const byte kInstruction_sbc_al_r4_r0_0x000001fe[] = {
  0x60, 0xf5, 0xff, 0x74 // sbc al r4 r0 0x000001fe
};
const byte kInstruction_sbc_al_r11_r9_0x0003fc00[] = {
  0x69, 0xf5, 0x7f, 0x3b // sbc al r11 r9 0x0003fc00
};
const byte kInstruction_sbc_al_r8_r3_0x00005580[] = {
  0x63, 0xf5, 0xab, 0x48 // sbc al r8 r3 0x00005580
};
const byte kInstruction_sbc_al_r4_r4_0xffffffff[] = {
  0x64, 0xf1, 0xff, 0x34 // sbc al r4 r4 0xffffffff
};
const byte kInstruction_sbc_al_r1_r9_0x00000558[] = {
  0x69, 0xf5, 0xab, 0x61 // sbc al r1 r9 0x00000558
};
const byte kInstruction_sbc_al_r9_r2_0x00ab0000[] = {
  0x62, 0xf5, 0x2b, 0x09 // sbc al r9 r2 0x00ab0000
};
const byte kInstruction_sbc_al_r11_r6_0x00003fc0[] = {
  0x66, 0xf5, 0x7f, 0x5b // sbc al r11 r6 0x00003fc0
};
const byte kInstruction_sbc_al_r11_r11_0x01fe0000[] = {
  0x6b, 0xf1, 0xff, 0x7b // sbc al r11 r11 0x01fe0000
};
const byte kInstruction_sbc_al_r6_r10_0x0001fe00[] = {
  0x6a, 0xf5, 0xff, 0x36 // sbc al r6 r10 0x0001fe00
};
const byte kInstruction_sbc_al_r8_r3_0x00000156[] = {
  0x63, 0xf5, 0xab, 0x78 // sbc al r8 r3 0x00000156
};
const byte kInstruction_sbc_al_r12_r12_0x0002ac00[] = {
  0x6c, 0xf5, 0x2b, 0x3c // sbc al r12 r12 0x0002ac00
};
const byte kInstruction_sbc_al_r8_r6_0x7f800000[] = {
  0x66, 0xf1, 0xff, 0x48 // sbc al r8 r6 0x7f800000
};
const byte kInstruction_sbc_al_r5_r13_0x000002ac[] = {
  0x6d, 0xf5, 0x2b, 0x75 // sbc al r5 r13 0x000002ac
};
const byte kInstruction_sbc_al_r5_r13_0x15600000[] = {
  0x6d, 0xf1, 0xab, 0x55 // sbc al r5 r13 0x15600000
};
const byte kInstruction_sbc_al_r8_r8_0x000000ab[] = {
  0x68, 0xf1, 0xab, 0x08 // sbc al r8 r8 0x000000ab
};
const byte kInstruction_sbc_al_r12_r14_0x00156000[] = {
  0x6e, 0xf5, 0xab, 0x1c // sbc al r12 r14 0x00156000
};
const byte kInstruction_sbc_al_r1_r7_0x003fc000[] = {
  0x67, 0xf5, 0x7f, 0x11 // sbc al r1 r7 0x003fc000
};
const byte kInstruction_sbc_al_r8_r0_0x00003fc0[] = {
  0x60, 0xf5, 0x7f, 0x58 // sbc al r8 r0 0x00003fc0
};
const byte kInstruction_sbc_al_r14_r11_0x0007f800[] = {
  0x6b, 0xf5, 0xff, 0x2e // sbc al r14 r11 0x0007f800
};
const byte kInstruction_sbc_al_r3_r8_0x00ab00ab[] = {
  0x68, 0xf1, 0xab, 0x13 // sbc al r3 r8 0x00ab00ab
};
const byte kInstruction_sbc_al_r14_r8_0x55800000[] = {
  0x68, 0xf1, 0xab, 0x4e // sbc al r14 r8 0x55800000
};
const byte kInstruction_sbc_al_r7_r8_0x000ff000[] = {
  0x68, 0xf5, 0x7f, 0x27 // sbc al r7 r8 0x000ff000
};
const byte kInstruction_sbc_al_r4_r11_0x01fe0000[] = {
  0x6b, 0xf1, 0xff, 0x74 // sbc al r4 r11 0x01fe0000
};
const byte kInstruction_sbc_al_r2_r4_0x01560000[] = {
  0x64, 0xf1, 0xab, 0x72 // sbc al r2 r4 0x01560000
};
const byte kInstruction_sbc_al_r4_r3_0xffffffff[] = {
  0x63, 0xf1, 0xff, 0x34 // sbc al r4 r3 0xffffffff
};
const byte kInstruction_sbc_al_r7_r8_0xab000000[] = {
  0x68, 0xf1, 0x2b, 0x47 // sbc al r7 r8 0xab000000
};
const byte kInstruction_sbc_al_r0_r13_0x00000ab0[] = {
  0x6d, 0xf5, 0x2b, 0x60 // sbc al r0 r13 0x00000ab0
};
const byte kInstruction_sbc_al_r1_r2_0x000001fe[] = {
  0x62, 0xf5, 0xff, 0x71 // sbc al r1 r2 0x000001fe
};
const byte kInstruction_sbc_al_r8_r14_0x02ac0000[] = {
  0x6e, 0xf1, 0x2b, 0x78 // sbc al r8 r14 0x02ac0000
};
const byte kInstruction_sbc_al_r4_r5_0x00558000[] = {
  0x65, 0xf5, 0xab, 0x04 // sbc al r4 r5 0x00558000
};
const byte kInstruction_sbc_al_r6_r7_0xff00ff00[] = {
  0x67, 0xf1, 0xff, 0x26 // sbc al r6 r7 0xff00ff00
};
const byte kInstruction_sbc_al_r8_r12_0x001fe000[] = {
  0x6c, 0xf5, 0xff, 0x18 // sbc al r8 r12 0x001fe000
};
const byte kInstruction_sbc_al_r6_r4_0x07f80000[] = {
  0x64, 0xf1, 0xff, 0x66 // sbc al r6 r4 0x07f80000
};
const byte kInstruction_sbc_al_r4_r0_0x00001fe0[] = {
  0x60, 0xf5, 0xff, 0x54 // sbc al r4 r0 0x00001fe0
};
const byte kInstruction_sbc_al_r14_r3_0xff00ff00[] = {
  0x63, 0xf1, 0xff, 0x2e // sbc al r14 r3 0xff00ff00
};
const byte kInstruction_sbc_al_r0_r6_0xab000000[] = {
  0x66, 0xf1, 0x2b, 0x40 // sbc al r0 r6 0xab000000
};
const byte kInstruction_sbc_al_r12_r13_0x00000ab0[] = {
  0x6d, 0xf5, 0x2b, 0x6c // sbc al r12 r13 0x00000ab0
};
const byte kInstruction_sbc_al_r12_r8_0x00000558[] = {
  0x68, 0xf5, 0xab, 0x6c // sbc al r12 r8 0x00000558
};
const byte kInstruction_sbc_al_r3_r12_0x0003fc00[] = {
  0x6c, 0xf5, 0x7f, 0x33 // sbc al r3 r12 0x0003fc00
};
const byte kInstruction_sbc_al_r2_r11_0x7f800000[] = {
  0x6b, 0xf1, 0xff, 0x42 // sbc al r2 r11 0x7f800000
};
const byte kInstruction_sbc_al_r10_r4_0x15600000[] = {
  0x64, 0xf1, 0xab, 0x5a // sbc al r10 r4 0x15600000
};
const byte kInstruction_sbc_al_r8_r7_0x0ab00000[] = {
  0x67, 0xf1, 0x2b, 0x68 // sbc al r8 r7 0x0ab00000
};
const byte kInstruction_sbc_al_r10_r6_0x000000ff[] = {
  0x66, 0xf1, 0xff, 0x0a // sbc al r10 r6 0x000000ff
};
const byte kInstruction_sbc_al_r3_r4_0xff00ff00[] = {
  0x64, 0xf1, 0xff, 0x23 // sbc al r3 r4 0xff00ff00
};
const byte kInstruction_sbc_al_r14_r10_0x00ab0000[] = {
  0x6a, 0xf5, 0x2b, 0x0e // sbc al r14 r10 0x00ab0000
};
const byte kInstruction_sbc_al_r8_r3_0x0002ac00[] = {
  0x63, 0xf5, 0x2b, 0x38 // sbc al r8 r3 0x0002ac00
};
const byte kInstruction_sbc_al_r8_r8_0x00000558[] = {
  0x68, 0xf5, 0xab, 0x68 // sbc al r8 r8 0x00000558
};
const byte kInstruction_sbc_al_r12_r4_0x00015600[] = {
  0x64, 0xf5, 0xab, 0x3c // sbc al r12 r4 0x00015600
};
const byte kInstruction_sbc_al_r8_r1_0x002ac000[] = {
  0x61, 0xf5, 0x2b, 0x18 // sbc al r8 r1 0x002ac000
};
const byte kInstruction_sbc_al_r8_r5_0x000000ab[] = {
  0x65, 0xf1, 0xab, 0x08 // sbc al r8 r5 0x000000ab
};
const byte kInstruction_sbc_al_r6_r6_0x000000ab[] = {
  0x66, 0xf1, 0xab, 0x06 // sbc al r6 r6 0x000000ab
};
const byte kInstruction_sbc_al_r5_r7_0x00002ac0[] = {
  0x67, 0xf5, 0x2b, 0x55 // sbc al r5 r7 0x00002ac0
};
const byte kInstruction_sbc_al_r11_r4_0x00000ff0[] = {
  0x64, 0xf5, 0x7f, 0x6b // sbc al r11 r4 0x00000ff0
};
const byte kInstruction_sbc_al_r9_r9_0x00000ff0[] = {
  0x69, 0xf5, 0x7f, 0x69 // sbc al r9 r9 0x00000ff0
};
const byte kInstruction_sbc_al_r0_r8_0x00ff0000[] = {
  0x68, 0xf5, 0x7f, 0x00 // sbc al r0 r8 0x00ff0000
};
const byte kInstruction_sbc_al_r9_r11_0x000000ab[] = {
  0x6b, 0xf1, 0xab, 0x09 // sbc al r9 r11 0x000000ab
};
const byte kInstruction_sbc_al_r7_r5_0x000000ff[] = {
  0x65, 0xf1, 0xff, 0x07 // sbc al r7 r5 0x000000ff
};
const byte kInstruction_sbc_al_r14_r0_0x15600000[] = {
  0x60, 0xf1, 0xab, 0x5e // sbc al r14 r0 0x15600000
};
const byte kInstruction_sbc_al_r10_r9_0x00000156[] = {
  0x69, 0xf5, 0xab, 0x7a // sbc al r10 r9 0x00000156
};
const byte kInstruction_sbc_al_r3_r7_0x00ff0000[] = {
  0x67, 0xf5, 0x7f, 0x03 // sbc al r3 r7 0x00ff0000
};
const byte kInstruction_sbc_al_r6_r11_0xab00ab00[] = {
  0x6b, 0xf1, 0xab, 0x26 // sbc al r6 r11 0xab00ab00
};
const byte kInstruction_sbc_al_r5_r2_0x002ac000[] = {
  0x62, 0xf5, 0x2b, 0x15 // sbc al r5 r2 0x002ac000
};
const byte kInstruction_sbc_al_r9_r14_0x55800000[] = {
  0x6e, 0xf1, 0xab, 0x49 // sbc al r9 r14 0x55800000
};
const byte kInstruction_sbc_al_r10_r13_0x15600000[] = {
  0x6d, 0xf1, 0xab, 0x5a // sbc al r10 r13 0x15600000
};
const byte kInstruction_sbc_al_r13_r7_0x0ff00000[] = {
  0x67, 0xf1, 0x7f, 0x6d // sbc al r13 r7 0x0ff00000
};
const byte kInstruction_sbc_al_r12_r5_0xffffffff[] = {
  0x65, 0xf1, 0xff, 0x3c // sbc al r12 r5 0xffffffff
};
const byte kInstruction_sbc_al_r8_r10_0x00000156[] = {
  0x6a, 0xf5, 0xab, 0x78 // sbc al r8 r10 0x00000156
};
const byte kInstruction_sbc_al_r7_r6_0x00005580[] = {
  0x66, 0xf5, 0xab, 0x47 // sbc al r7 r6 0x00005580
};
const byte kInstruction_sbc_al_r6_r6_0x0ab00000[] = {
  0x66, 0xf1, 0x2b, 0x66 // sbc al r6 r6 0x0ab00000
};
const byte kInstruction_sbc_al_r3_r7_0x01fe0000[] = {
  0x67, 0xf1, 0xff, 0x73 // sbc al r3 r7 0x01fe0000
};
const byte kInstruction_sbc_al_r14_r9_0x00558000[] = {
  0x69, 0xf5, 0xab, 0x0e // sbc al r14 r9 0x00558000
};
const byte kInstruction_sbc_al_r3_r13_0x000007f8[] = {
  0x6d, 0xf5, 0xff, 0x63 // sbc al r3 r13 0x000007f8
};
const byte kInstruction_sbc_al_r10_r2_0x00055800[] = {
  0x62, 0xf5, 0xab, 0x2a // sbc al r10 r2 0x00055800
};
const byte kInstruction_sbc_al_r5_r14_0x00005580[] = {
  0x6e, 0xf5, 0xab, 0x45 // sbc al r5 r14 0x00005580
};
const byte kInstruction_sbc_al_r9_r12_0xab000000[] = {
  0x6c, 0xf1, 0x2b, 0x49 // sbc al r9 r12 0xab000000
};
const byte kInstruction_sbc_al_r2_r14_0x00000156[] = {
  0x6e, 0xf5, 0xab, 0x72 // sbc al r2 r14 0x00000156
};
const byte kInstruction_sbc_al_r6_r10_0x000ff000[] = {
  0x6a, 0xf5, 0x7f, 0x26 // sbc al r6 r10 0x000ff000
};
const byte kInstruction_sbc_al_r6_r7_0x000007f8[] = {
  0x67, 0xf5, 0xff, 0x66 // sbc al r6 r7 0x000007f8
};
const byte kInstruction_sbc_al_r8_r3_0x7f800000[] = {
  0x63, 0xf1, 0xff, 0x48 // sbc al r8 r3 0x7f800000
};
const byte kInstruction_sbc_al_r0_r12_0x15600000[] = {
  0x6c, 0xf1, 0xab, 0x50 // sbc al r0 r12 0x15600000
};
const byte kInstruction_sbc_al_r1_r6_0x00558000[] = {
  0x66, 0xf5, 0xab, 0x01 // sbc al r1 r6 0x00558000
};
const byte kInstruction_sbc_al_r3_r8_0x55800000[] = {
  0x68, 0xf1, 0xab, 0x43 // sbc al r3 r8 0x55800000
};
const byte kInstruction_sbc_al_r1_r14_0x000003fc[] = {
  0x6e, 0xf5, 0x7f, 0x71 // sbc al r1 r14 0x000003fc
};
const byte kInstruction_sbc_al_r0_r2_0x0ab00000[] = {
  0x62, 0xf1, 0x2b, 0x60 // sbc al r0 r2 0x0ab00000
};
const byte kInstruction_sbc_al_r10_r12_0x00000156[] = {
  0x6c, 0xf5, 0xab, 0x7a // sbc al r10 r12 0x00000156
};
const byte kInstruction_sbc_al_r12_r14_0x03fc0000[] = {
  0x6e, 0xf1, 0x7f, 0x7c // sbc al r12 r14 0x03fc0000
};
const byte kInstruction_sbc_al_r2_r5_0x0001fe00[] = {
  0x65, 0xf5, 0xff, 0x32 // sbc al r2 r5 0x0001fe00
};
const byte kInstruction_sbc_al_r5_r11_0x000ab000[] = {
  0x6b, 0xf5, 0x2b, 0x25 // sbc al r5 r11 0x000ab000
};
const byte kInstruction_sbc_al_r14_r14_0x0001fe00[] = {
  0x6e, 0xf5, 0xff, 0x3e // sbc al r14 r14 0x0001fe00
};
const byte kInstruction_sbc_al_r13_r2_0x00003fc0[] = {
  0x62, 0xf5, 0x7f, 0x5d // sbc al r13 r2 0x00003fc0
};
const byte kInstruction_sbc_al_r0_r8_0xab000000[] = {
  0x68, 0xf1, 0x2b, 0x40 // sbc al r0 r8 0xab000000
};
const byte kInstruction_sbc_al_r12_r0_0x000000ab[] = {
  0x60, 0xf1, 0xab, 0x0c // sbc al r12 r0 0x000000ab
};
const byte kInstruction_sbc_al_r11_r10_0x002ac000[] = {
  0x6a, 0xf5, 0x2b, 0x1b // sbc al r11 r10 0x002ac000
};
const byte kInstruction_sbc_al_r12_r11_0x00ab0000[] = {
  0x6b, 0xf5, 0x2b, 0x0c // sbc al r12 r11 0x00ab0000
};
const byte kInstruction_sbc_al_r2_r9_0x0ff00000[] = {
  0x69, 0xf1, 0x7f, 0x62 // sbc al r2 r9 0x0ff00000
};
const byte kInstruction_sbc_al_r7_r4_0x000001fe[] = {
  0x64, 0xf5, 0xff, 0x77 // sbc al r7 r4 0x000001fe
};
const byte kInstruction_sbc_al_r7_r6_0x0000ff00[] = {
  0x66, 0xf5, 0x7f, 0x47 // sbc al r7 r6 0x0000ff00
};
const byte kInstruction_sbc_al_r11_r14_0x05580000[] = {
  0x6e, 0xf1, 0xab, 0x6b // sbc al r11 r14 0x05580000
};
const byte kInstruction_sbc_al_r6_r10_0x00000558[] = {
  0x6a, 0xf5, 0xab, 0x66 // sbc al r6 r10 0x00000558
};
const byte kInstruction_sbc_al_r11_r6_0x0001fe00[] = {
  0x66, 0xf5, 0xff, 0x3b // sbc al r11 r6 0x0001fe00
};
const byte kInstruction_sbc_al_r11_r12_0xab00ab00[] = {
  0x6c, 0xf1, 0xab, 0x2b // sbc al r11 r12 0xab00ab00
};
const byte kInstruction_sbc_al_r1_r8_0x7f800000[] = {
  0x68, 0xf1, 0xff, 0x41 // sbc al r1 r8 0x7f800000
};
const byte kInstruction_sbc_al_r4_r3_0x0000ff00[] = {
  0x63, 0xf5, 0x7f, 0x44 // sbc al r4 r3 0x0000ff00
};
const byte kInstruction_sbc_al_r5_r4_0x00ff00ff[] = {
  0x64, 0xf1, 0xff, 0x15 // sbc al r5 r4 0x00ff00ff
};
const byte kInstruction_sbc_al_r12_r11_0x2ac00000[] = {
  0x6b, 0xf1, 0x2b, 0x5c // sbc al r12 r11 0x2ac00000
};
const byte kInstruction_sbc_al_r1_r6_0xab00ab00[] = {
  0x66, 0xf1, 0xab, 0x21 // sbc al r1 r6 0xab00ab00
};
const byte kInstruction_sbc_al_r6_r3_0x000000ab[] = {
  0x63, 0xf1, 0xab, 0x06 // sbc al r6 r3 0x000000ab
};
const byte kInstruction_sbc_al_r2_r11_0x0007f800[] = {
  0x6b, 0xf5, 0xff, 0x22 // sbc al r2 r11 0x0007f800
};
const byte kInstruction_sbc_al_r3_r0_0x00001560[] = {
  0x60, 0xf5, 0xab, 0x53 // sbc al r3 r0 0x00001560
};
const byte kInstruction_sbc_al_r1_r14_0x00000558[] = {
  0x6e, 0xf5, 0xab, 0x61 // sbc al r1 r14 0x00000558
};
const byte kInstruction_sbc_al_r10_r8_0x00558000[] = {
  0x68, 0xf5, 0xab, 0x0a // sbc al r10 r8 0x00558000
};
const byte kInstruction_sbc_al_r0_r8_0x000ff000[] = {
  0x68, 0xf5, 0x7f, 0x20 // sbc al r0 r8 0x000ff000
};
const byte kInstruction_sbc_al_r13_r6_0x007f8000[] = {
  0x66, 0xf5, 0xff, 0x0d // sbc al r13 r6 0x007f8000
};
const byte kInstruction_sbc_al_r3_r10_0x000002ac[] = {
  0x6a, 0xf5, 0x2b, 0x73 // sbc al r3 r10 0x000002ac
};
const byte kInstruction_sbc_al_r12_r2_0x0003fc00[] = {
  0x62, 0xf5, 0x7f, 0x3c // sbc al r12 r2 0x0003fc00
};
const byte kInstruction_sbc_al_r5_r5_0x02ac0000[] = {
  0x65, 0xf1, 0x2b, 0x75 // sbc al r5 r5 0x02ac0000
};
const byte kInstruction_sbc_al_r11_r12_0x001fe000[] = {
  0x6c, 0xf5, 0xff, 0x1b // sbc al r11 r12 0x001fe000
};
const byte kInstruction_sbc_al_r0_r14_0x001fe000[] = {
  0x6e, 0xf5, 0xff, 0x10 // sbc al r0 r14 0x001fe000
};
const byte kInstruction_sbc_al_r0_r14_0x02ac0000[] = {
  0x6e, 0xf1, 0x2b, 0x70 // sbc al r0 r14 0x02ac0000
};
const byte kInstruction_sbc_al_r6_r7_0x0ff00000[] = {
  0x67, 0xf1, 0x7f, 0x66 // sbc al r6 r7 0x0ff00000
};
const byte kInstruction_sbc_al_r10_r13_0x00000156[] = {
  0x6d, 0xf5, 0xab, 0x7a // sbc al r10 r13 0x00000156
};
const byte kInstruction_sbc_al_r3_r7_0x000007f8[] = {
  0x67, 0xf5, 0xff, 0x63 // sbc al r3 r7 0x000007f8
};
const byte kInstruction_sbc_al_r4_r10_0x000000ab[] = {
  0x6a, 0xf1, 0xab, 0x04 // sbc al r4 r10 0x000000ab
};
const byte kInstruction_sbc_al_r0_r6_0x00000558[] = {
  0x66, 0xf5, 0xab, 0x60 // sbc al r0 r6 0x00000558
};
const byte kInstruction_sbc_al_r1_r1_0x05580000[] = {
  0x61, 0xf1, 0xab, 0x61 // sbc al r1 r1 0x05580000
};
const byte kInstruction_sbc_al_r8_r2_0x00001560[] = {
  0x62, 0xf5, 0xab, 0x58 // sbc al r8 r2 0x00001560
};
const byte kInstruction_sbc_al_r9_r5_0x0001fe00[] = {
  0x65, 0xf5, 0xff, 0x39 // sbc al r9 r5 0x0001fe00
};
const byte kInstruction_sbc_al_r13_r9_0x0ab00000[] = {
  0x69, 0xf1, 0x2b, 0x6d // sbc al r13 r9 0x0ab00000
};
const byte kInstruction_sbc_al_r13_r9_0x00007f80[] = {
  0x69, 0xf5, 0xff, 0x4d // sbc al r13 r9 0x00007f80
};
const byte kInstruction_sbc_al_r10_r5_0x0000ab00[] = {
  0x65, 0xf5, 0x2b, 0x4a // sbc al r10 r5 0x0000ab00
};
const byte kInstruction_sbc_al_r6_r13_0x007f8000[] = {
  0x6d, 0xf5, 0xff, 0x06 // sbc al r6 r13 0x007f8000
};
const byte kInstruction_sbc_al_r5_r9_0x000ab000[] = {
  0x69, 0xf5, 0x2b, 0x25 // sbc al r5 r9 0x000ab000
};
const byte kInstruction_sbc_al_r4_r4_0x000000ab[] = {
  0x64, 0xf1, 0xab, 0x04 // sbc al r4 r4 0x000000ab
};
const byte kInstruction_sbc_al_r13_r5_0xab00ab00[] = {
  0x65, 0xf1, 0xab, 0x2d // sbc al r13 r5 0xab00ab00
};
const byte kInstruction_sbc_al_r12_r3_0x00005580[] = {
  0x63, 0xf5, 0xab, 0x4c // sbc al r12 r3 0x00005580
};
const byte kInstruction_sbc_al_r0_r10_0x55800000[] = {
  0x6a, 0xf1, 0xab, 0x40 // sbc al r0 r10 0x55800000
};
const byte kInstruction_sbc_al_r2_r8_0x00ab00ab[] = {
  0x68, 0xf1, 0xab, 0x12 // sbc al r2 r8 0x00ab00ab
};
const byte kInstruction_sbc_al_r11_r5_0x0003fc00[] = {
  0x65, 0xf5, 0x7f, 0x3b // sbc al r11 r5 0x0003fc00
};
const byte kInstruction_sbc_al_r11_r0_0x00ab0000[] = {
  0x60, 0xf5, 0x2b, 0x0b // sbc al r11 r0 0x00ab0000
};
const byte kInstruction_sbc_al_r10_r2_0x000002ac[] = {
  0x62, 0xf5, 0x2b, 0x7a // sbc al r10 r2 0x000002ac
};
const byte kInstruction_sbc_al_r11_r12_0x00055800[] = {
  0x6c, 0xf5, 0xab, 0x2b // sbc al r11 r12 0x00055800
};
const byte kInstruction_sbc_al_r5_r13_0x00000ff0[] = {
  0x6d, 0xf5, 0x7f, 0x65 // sbc al r5 r13 0x00000ff0
};
const byte kInstruction_sbc_al_r4_r14_0x15600000[] = {
  0x6e, 0xf1, 0xab, 0x54 // sbc al r4 r14 0x15600000
};
const byte kInstruction_sbc_al_r10_r1_0x00003fc0[] = {
  0x61, 0xf5, 0x7f, 0x5a // sbc al r10 r1 0x00003fc0
};
const byte kInstruction_sbc_al_r14_r8_0xff000000[] = {
  0x68, 0xf1, 0x7f, 0x4e // sbc al r14 r8 0xff000000
};
const byte kInstruction_sbc_al_r12_r0_0x00ff0000[] = {
  0x60, 0xf5, 0x7f, 0x0c // sbc al r12 r0 0x00ff0000
};
const byte kInstruction_sbc_al_r4_r5_0x3fc00000[] = {
  0x65, 0xf1, 0x7f, 0x54 // sbc al r4 r5 0x3fc00000
};
const byte kInstruction_sbc_al_r14_r10_0x3fc00000[] = {
  0x6a, 0xf1, 0x7f, 0x5e // sbc al r14 r10 0x3fc00000
};
const byte kInstruction_sbc_al_r10_r1_0x00015600[] = {
  0x61, 0xf5, 0xab, 0x3a // sbc al r10 r1 0x00015600
};
const byte kInstruction_sbc_al_r4_r3_0xff000000[] = {
  0x63, 0xf1, 0x7f, 0x44 // sbc al r4 r3 0xff000000
};
const byte kInstruction_sbc_al_r10_r10_0x02ac0000[] = {
  0x6a, 0xf1, 0x2b, 0x7a // sbc al r10 r10 0x02ac0000
};
const byte kInstruction_sbc_al_r9_r9_0x000ff000[] = {
  0x69, 0xf5, 0x7f, 0x29 // sbc al r9 r9 0x000ff000
};
const byte kInstruction_sbc_al_r13_r7_0x0002ac00[] = {
  0x67, 0xf5, 0x2b, 0x3d // sbc al r13 r7 0x0002ac00
};
const byte kInstruction_sbc_al_r7_r8_0x00001fe0[] = {
  0x68, 0xf5, 0xff, 0x57 // sbc al r7 r8 0x00001fe0
};
const byte kInstruction_sbc_al_r2_r4_0x00001560[] = {
  0x64, 0xf5, 0xab, 0x52 // sbc al r2 r4 0x00001560
};
const byte kInstruction_sbc_al_r13_r7_0x00156000[] = {
  0x67, 0xf5, 0xab, 0x1d // sbc al r13 r7 0x00156000
};
const byte kInstruction_sbc_al_r9_r9_0x000003fc[] = {
  0x69, 0xf5, 0x7f, 0x79 // sbc al r9 r9 0x000003fc
};
const byte kInstruction_sbc_al_r0_r3_0x000ab000[] = {
  0x63, 0xf5, 0x2b, 0x20 // sbc al r0 r3 0x000ab000
};
const byte kInstruction_sbc_al_r10_r12_0x0000ab00[] = {
  0x6c, 0xf5, 0x2b, 0x4a // sbc al r10 r12 0x0000ab00
};
const byte kInstruction_sbc_al_r1_r13_0x00002ac0[] = {
  0x6d, 0xf5, 0x2b, 0x51 // sbc al r1 r13 0x00002ac0
};
const byte kInstruction_sbc_al_r3_r10_0x001fe000[] = {
  0x6a, 0xf5, 0xff, 0x13 // sbc al r3 r10 0x001fe000
};
const byte kInstruction_sbc_al_r4_r12_0x00ff00ff[] = {
  0x6c, 0xf1, 0xff, 0x14 // sbc al r4 r12 0x00ff00ff
};
const byte kInstruction_sbc_al_r12_r5_0x003fc000[] = {
  0x65, 0xf5, 0x7f, 0x1c // sbc al r12 r5 0x003fc000
};
const byte kInstruction_sbc_al_r11_r2_0x0001fe00[] = {
  0x62, 0xf5, 0xff, 0x3b // sbc al r11 r2 0x0001fe00
};
const byte kInstruction_sbc_al_r8_r6_0x0007f800[] = {
  0x66, 0xf5, 0xff, 0x28 // sbc al r8 r6 0x0007f800
};
const byte kInstruction_sbc_al_r11_r1_0x000000ff[] = {
  0x61, 0xf1, 0xff, 0x0b // sbc al r11 r1 0x000000ff
};
const byte kInstruction_sbc_al_r5_r2_0x007f8000[] = {
  0x62, 0xf5, 0xff, 0x05 // sbc al r5 r2 0x007f8000
};
const byte kInstruction_sbc_al_r8_r10_0xab000000[] = {
  0x6a, 0xf1, 0x2b, 0x48 // sbc al r8 r10 0xab000000
};
const byte kInstruction_sbc_al_r10_r3_0x000ff000[] = {
  0x63, 0xf5, 0x7f, 0x2a // sbc al r10 r3 0x000ff000
};
const byte kInstruction_sbc_al_r6_r0_0x00ff0000[] = {
  0x60, 0xf5, 0x7f, 0x06 // sbc al r6 r0 0x00ff0000
};
const byte kInstruction_sbc_al_r7_r14_0x0ff00000[] = {
  0x6e, 0xf1, 0x7f, 0x67 // sbc al r7 r14 0x0ff00000
};
const byte kInstruction_sbc_al_r8_r3_0x00001560[] = {
  0x63, 0xf5, 0xab, 0x58 // sbc al r8 r3 0x00001560
};
const byte kInstruction_sbc_al_r13_r9_0x00000558[] = {
  0x69, 0xf5, 0xab, 0x6d // sbc al r13 r9 0x00000558
};
const byte kInstruction_sbc_al_r8_r7_0x00001fe0[] = {
  0x67, 0xf5, 0xff, 0x58 // sbc al r8 r7 0x00001fe0
};
const byte kInstruction_sbc_al_r13_r3_0x0003fc00[] = {
  0x63, 0xf5, 0x7f, 0x3d // sbc al r13 r3 0x0003fc00
};
const byte kInstruction_sbc_al_r4_r14_0x000000ab[] = {
  0x6e, 0xf1, 0xab, 0x04 // sbc al r4 r14 0x000000ab
};
const byte kInstruction_sbc_al_r14_r7_0x000000ab[] = {
  0x67, 0xf1, 0xab, 0x0e // sbc al r14 r7 0x000000ab
};
const byte kInstruction_sbc_al_r11_r9_0x00558000[] = {
  0x69, 0xf5, 0xab, 0x0b // sbc al r11 r9 0x00558000
};
const byte kInstruction_sbc_al_r3_r10_0x0000ff00[] = {
  0x6a, 0xf5, 0x7f, 0x43 // sbc al r3 r10 0x0000ff00
};
const byte kInstruction_sbc_al_r4_r12_0x003fc000[] = {
  0x6c, 0xf5, 0x7f, 0x14 // sbc al r4 r12 0x003fc000
};
const byte kInstruction_sbc_al_r11_r1_0x002ac000[] = {
  0x61, 0xf5, 0x2b, 0x1b // sbc al r11 r1 0x002ac000
};
const byte kInstruction_sbc_al_r12_r0_0x7f800000[] = {
  0x60, 0xf1, 0xff, 0x4c // sbc al r12 r0 0x7f800000
};
const byte kInstruction_sbc_al_r3_r9_0x00003fc0[] = {
  0x69, 0xf5, 0x7f, 0x53 // sbc al r3 r9 0x00003fc0
};
const byte kInstruction_sbc_al_r6_r6_0x0ff00000[] = {
  0x66, 0xf1, 0x7f, 0x66 // sbc al r6 r6 0x0ff00000
};
const byte kInstruction_sbc_al_r1_r11_0xff000000[] = {
  0x6b, 0xf1, 0x7f, 0x41 // sbc al r1 r11 0xff000000
};
const byte kInstruction_sbc_al_r2_r10_0x0007f800[] = {
  0x6a, 0xf5, 0xff, 0x22 // sbc al r2 r10 0x0007f800
};
const byte kInstruction_sbc_al_r12_r10_0x000002ac[] = {
  0x6a, 0xf5, 0x2b, 0x7c // sbc al r12 r10 0x000002ac
};
const byte kInstruction_sbc_al_r10_r8_0x000003fc[] = {
  0x68, 0xf5, 0x7f, 0x7a // sbc al r10 r8 0x000003fc
};
const byte kInstruction_sbc_al_r9_r0_0x55800000[] = {
  0x60, 0xf1, 0xab, 0x49 // sbc al r9 r0 0x55800000
};
const byte kInstruction_sbc_al_r8_r7_0x1fe00000[] = {
  0x67, 0xf1, 0xff, 0x58 // sbc al r8 r7 0x1fe00000
};
const byte kInstruction_sbc_al_r4_r0_0x15600000[] = {
  0x60, 0xf1, 0xab, 0x54 // sbc al r4 r0 0x15600000
};
const byte kInstruction_sbc_al_r4_r0_0xff00ff00[] = {
  0x60, 0xf1, 0xff, 0x24 // sbc al r4 r0 0xff00ff00
};
const byte kInstruction_sbc_al_r1_r14_0x00007f80[] = {
  0x6e, 0xf5, 0xff, 0x41 // sbc al r1 r14 0x00007f80
};
const byte kInstruction_sbc_al_r7_r3_0x00ff00ff[] = {
  0x63, 0xf1, 0xff, 0x17 // sbc al r7 r3 0x00ff00ff
};
const byte kInstruction_sbc_al_r10_r2_0x00001560[] = {
  0x62, 0xf5, 0xab, 0x5a // sbc al r10 r2 0x00001560
};
const byte kInstruction_sbc_al_r0_r14_0xabababab[] = {
  0x6e, 0xf1, 0xab, 0x30 // sbc al r0 r14 0xabababab
};
const byte kInstruction_sbc_al_r3_r4_0x007f8000[] = {
  0x64, 0xf5, 0xff, 0x03 // sbc al r3 r4 0x007f8000
};
const byte kInstruction_sbc_al_r0_r2_0x003fc000[] = {
  0x62, 0xf5, 0x7f, 0x10 // sbc al r0 r2 0x003fc000
};
const byte kInstruction_sbc_al_r13_r6_0x0002ac00[] = {
  0x66, 0xf5, 0x2b, 0x3d // sbc al r13 r6 0x0002ac00
};
const byte kInstruction_sbc_al_r11_r5_0x00001fe0[] = {
  0x65, 0xf5, 0xff, 0x5b // sbc al r11 r5 0x00001fe0
};
const byte kInstruction_sbc_al_r1_r13_0x00005580[] = {
  0x6d, 0xf5, 0xab, 0x41 // sbc al r1 r13 0x00005580
};
const byte kInstruction_sbc_al_r13_r8_0x000007f8[] = {
  0x68, 0xf5, 0xff, 0x6d // sbc al r13 r8 0x000007f8
};
const byte kInstruction_sbc_al_r6_r4_0x0ab00000[] = {
  0x64, 0xf1, 0x2b, 0x66 // sbc al r6 r4 0x0ab00000
};
const byte kInstruction_sbc_al_r14_r10_0x1fe00000[] = {
  0x6a, 0xf1, 0xff, 0x5e // sbc al r14 r10 0x1fe00000
};
const byte kInstruction_sbc_al_r7_r6_0xff00ff00[] = {
  0x66, 0xf1, 0xff, 0x27 // sbc al r7 r6 0xff00ff00
};
const byte kInstruction_sbc_al_r11_r5_0xffffffff[] = {
  0x65, 0xf1, 0xff, 0x3b // sbc al r11 r5 0xffffffff
};
const byte kInstruction_sbc_al_r0_r12_0xffffffff[] = {
  0x6c, 0xf1, 0xff, 0x30 // sbc al r0 r12 0xffffffff
};
const byte kInstruction_sbc_al_r12_r2_0x15600000[] = {
  0x62, 0xf1, 0xab, 0x5c // sbc al r12 r2 0x15600000
};
const byte kInstruction_sbc_al_r3_r12_0x000ff000[] = {
  0x6c, 0xf5, 0x7f, 0x23 // sbc al r3 r12 0x000ff000
};
const byte kInstruction_sbc_al_r6_r8_0x00055800[] = {
  0x68, 0xf5, 0xab, 0x26 // sbc al r6 r8 0x00055800
};
const byte kInstruction_sbc_al_r12_r7_0x05580000[] = {
  0x67, 0xf1, 0xab, 0x6c // sbc al r12 r7 0x05580000
};
const byte kInstruction_sbc_al_r8_r5_0x007f8000[] = {
  0x65, 0xf5, 0xff, 0x08 // sbc al r8 r5 0x007f8000
};
const byte kInstruction_sbc_al_r4_r1_0x000ab000[] = {
  0x61, 0xf5, 0x2b, 0x24 // sbc al r4 r1 0x000ab000
};
const byte kInstruction_sbc_al_r13_r12_0x02ac0000[] = {
  0x6c, 0xf1, 0x2b, 0x7d // sbc al r13 r12 0x02ac0000
};
const byte kInstruction_sbc_al_r9_r8_0x000000ff[] = {
  0x68, 0xf1, 0xff, 0x09 // sbc al r9 r8 0x000000ff
};
const byte kInstruction_sbc_al_r1_r11_0x00005580[] = {
  0x6b, 0xf5, 0xab, 0x41 // sbc al r1 r11 0x00005580
};
const byte kInstruction_sbc_al_r10_r12_0x02ac0000[] = {
  0x6c, 0xf1, 0x2b, 0x7a // sbc al r10 r12 0x02ac0000
};
const byte kInstruction_sbc_al_r7_r9_0x00ab00ab[] = {
  0x69, 0xf1, 0xab, 0x17 // sbc al r7 r9 0x00ab00ab
};
const byte kInstruction_sbc_al_r0_r5_0x0000ab00[] = {
  0x65, 0xf5, 0x2b, 0x40 // sbc al r0 r5 0x0000ab00
};
const byte kInstruction_sbc_al_r13_r9_0x00558000[] = {
  0x69, 0xf5, 0xab, 0x0d // sbc al r13 r9 0x00558000
};
const byte kInstruction_sbc_al_r0_r1_0x002ac000[] = {
  0x61, 0xf5, 0x2b, 0x10 // sbc al r0 r1 0x002ac000
};
const byte kInstruction_sbc_al_r14_r1_0x00000ab0[] = {
  0x61, 0xf5, 0x2b, 0x6e // sbc al r14 r1 0x00000ab0
};
const byte kInstruction_sbc_al_r2_r2_0x00000558[] = {
  0x62, 0xf5, 0xab, 0x62 // sbc al r2 r2 0x00000558
};
const byte kInstruction_sbc_al_r10_r13_0x00ab00ab[] = {
  0x6d, 0xf1, 0xab, 0x1a // sbc al r10 r13 0x00ab00ab
};
const byte kInstruction_sbc_al_r4_r6_0x00001560[] = {
  0x66, 0xf5, 0xab, 0x54 // sbc al r4 r6 0x00001560
};
const byte kInstruction_sbc_al_r10_r0_0x00156000[] = {
  0x60, 0xf5, 0xab, 0x1a // sbc al r10 r0 0x00156000
};
const byte kInstruction_sbc_al_r10_r13_0x00156000[] = {
  0x6d, 0xf5, 0xab, 0x1a // sbc al r10 r13 0x00156000
};
const byte kInstruction_sbc_al_r11_r2_0x001fe000[] = {
  0x62, 0xf5, 0xff, 0x1b // sbc al r11 r2 0x001fe000
};
const byte kInstruction_sbc_al_r4_r5_0x2ac00000[] = {
  0x65, 0xf1, 0x2b, 0x54 // sbc al r4 r5 0x2ac00000
};
const byte kInstruction_sbc_al_r8_r8_0x02ac0000[] = {
  0x68, 0xf1, 0x2b, 0x78 // sbc al r8 r8 0x02ac0000
};
const byte kInstruction_sbc_al_r9_r1_0x7f800000[] = {
  0x61, 0xf1, 0xff, 0x49 // sbc al r9 r1 0x7f800000
};
const byte kInstruction_sbc_al_r8_r9_0xff00ff00[] = {
  0x69, 0xf1, 0xff, 0x28 // sbc al r8 r9 0xff00ff00
};
const byte kInstruction_sbc_al_r12_r7_0x00ff00ff[] = {
  0x67, 0xf1, 0xff, 0x1c // sbc al r12 r7 0x00ff00ff
};
const byte kInstruction_sbc_al_r9_r10_0x00156000[] = {
  0x6a, 0xf5, 0xab, 0x19 // sbc al r9 r10 0x00156000
};
const TestResult kReferencesbc[] = {
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r14_0x02ac0000),
    kInstruction_sbc_al_r13_r14_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r1_0x00156000),
    kInstruction_sbc_al_r10_r1_0x00156000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r0_0x000003fc),
    kInstruction_sbc_al_r10_r0_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r11_0x2ac00000),
    kInstruction_sbc_al_r1_r11_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r6_0x00156000),
    kInstruction_sbc_al_r8_r6_0x00156000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r12_0x00ff0000),
    kInstruction_sbc_al_r7_r12_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r3_0x00ff0000),
    kInstruction_sbc_al_r12_r3_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r7_0x0000ff00),
    kInstruction_sbc_al_r4_r7_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r13_0x0ab00000),
    kInstruction_sbc_al_r11_r13_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r12_0xff00ff00),
    kInstruction_sbc_al_r6_r12_0xff00ff00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r8_0x003fc000),
    kInstruction_sbc_al_r12_r8_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r12_0x00ab00ab),
    kInstruction_sbc_al_r5_r12_0x00ab00ab,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r6_0x00ab00ab),
    kInstruction_sbc_al_r7_r6_0x00ab00ab,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r1_0x00ab00ab),
    kInstruction_sbc_al_r0_r1_0x00ab00ab,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r9_0x000001fe),
    kInstruction_sbc_al_r9_r9_0x000001fe,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r8_0xab00ab00),
    kInstruction_sbc_al_r2_r8_0xab00ab00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r10_0x00ff0000),
    kInstruction_sbc_al_r9_r10_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r8_0x55800000),
    kInstruction_sbc_al_r8_r8_0x55800000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r7_0x00ab00ab),
    kInstruction_sbc_al_r6_r7_0x00ab00ab,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r9_0xff000000),
    kInstruction_sbc_al_r5_r9_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r8_0x00ab0000),
    kInstruction_sbc_al_r8_r8_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r8_0xab00ab00),
    kInstruction_sbc_al_r5_r8_0xab00ab00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r12_0xab000000),
    kInstruction_sbc_al_r0_r12_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r11_0xab000000),
    kInstruction_sbc_al_r13_r11_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r3_0xab00ab00),
    kInstruction_sbc_al_r14_r3_0xab00ab00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r1_0x0003fc00),
    kInstruction_sbc_al_r0_r1_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r13_0x0ab00000),
    kInstruction_sbc_al_r14_r13_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r0_0x0002ac00),
    kInstruction_sbc_al_r6_r0_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r8_0x55800000),
    kInstruction_sbc_al_r6_r8_0x55800000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r14_0x01560000),
    kInstruction_sbc_al_r2_r14_0x01560000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r13_0x03fc0000),
    kInstruction_sbc_al_r5_r13_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r6_0x00000ab0),
    kInstruction_sbc_al_r7_r6_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r14_0x007f8000),
    kInstruction_sbc_al_r3_r14_0x007f8000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r4_0x00558000),
    kInstruction_sbc_al_r9_r4_0x00558000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r11_0x00002ac0),
    kInstruction_sbc_al_r10_r11_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r5_0x003fc000),
    kInstruction_sbc_al_r1_r5_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r7_0x00003fc0),
    kInstruction_sbc_al_r7_r7_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r3_0x000007f8),
    kInstruction_sbc_al_r5_r3_0x000007f8,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r3_0x00001560),
    kInstruction_sbc_al_r4_r3_0x00001560,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r3_0x03fc0000),
    kInstruction_sbc_al_r5_r3_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r6_0x55800000),
    kInstruction_sbc_al_r2_r6_0x55800000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r5_0x0000ab00),
    kInstruction_sbc_al_r13_r5_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r11_0xab00ab00),
    kInstruction_sbc_al_r0_r11_0xab00ab00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r12_0x00ff00ff),
    kInstruction_sbc_al_r14_r12_0x00ff00ff,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r8_0x7f800000),
    kInstruction_sbc_al_r13_r8_0x7f800000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r2_0x15600000),
    kInstruction_sbc_al_r1_r2_0x15600000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r6_0xab000000),
    kInstruction_sbc_al_r7_r6_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r9_0x00000ff0),
    kInstruction_sbc_al_r1_r9_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r8_0x0007f800),
    kInstruction_sbc_al_r12_r8_0x0007f800,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r8_0x00ab0000),
    kInstruction_sbc_al_r0_r8_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r11_0x000000ff),
    kInstruction_sbc_al_r11_r11_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r13_0xff000000),
    kInstruction_sbc_al_r12_r13_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r3_0x0ab00000),
    kInstruction_sbc_al_r1_r3_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r10_0x0001fe00),
    kInstruction_sbc_al_r2_r10_0x0001fe00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r2_0x01fe0000),
    kInstruction_sbc_al_r14_r2_0x01fe0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r4_0x000000ff),
    kInstruction_sbc_al_r3_r4_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r13_0x00000558),
    kInstruction_sbc_al_r3_r13_0x00000558,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r10_0x00055800),
    kInstruction_sbc_al_r13_r10_0x00055800,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r10_0xff000000),
    kInstruction_sbc_al_r1_r10_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r7_0x2ac00000),
    kInstruction_sbc_al_r0_r7_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r1_0xab000000),
    kInstruction_sbc_al_r12_r1_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r14_0x00003fc0),
    kInstruction_sbc_al_r9_r14_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r2_0x2ac00000),
    kInstruction_sbc_al_r7_r2_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r4_0x00001fe0),
    kInstruction_sbc_al_r14_r4_0x00001fe0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r8_0x00007f80),
    kInstruction_sbc_al_r12_r8_0x00007f80,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r10_0x00000ab0),
    kInstruction_sbc_al_r7_r10_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r6_0x00ab0000),
    kInstruction_sbc_al_r13_r6_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r9_0x0000ff00),
    kInstruction_sbc_al_r7_r9_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r12_0xff00ff00),
    kInstruction_sbc_al_r2_r12_0xff00ff00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r6_0x00000156),
    kInstruction_sbc_al_r1_r6_0x00000156,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r5_0x03fc0000),
    kInstruction_sbc_al_r7_r5_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r9_0x01fe0000),
    kInstruction_sbc_al_r2_r9_0x01fe0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r12_0x00002ac0),
    kInstruction_sbc_al_r10_r12_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r10_0x7f800000),
    kInstruction_sbc_al_r14_r10_0x7f800000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r8_0x02ac0000),
    kInstruction_sbc_al_r2_r8_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r9_0x000001fe),
    kInstruction_sbc_al_r4_r9_0x000001fe,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r10_0x000001fe),
    kInstruction_sbc_al_r10_r10_0x000001fe,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r6_0x3fc00000),
    kInstruction_sbc_al_r6_r6_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r12_0x000003fc),
    kInstruction_sbc_al_r4_r12_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r2_0x0000ff00),
    kInstruction_sbc_al_r0_r2_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r0_0x003fc000),
    kInstruction_sbc_al_r9_r0_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r4_0x000002ac),
    kInstruction_sbc_al_r7_r4_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r6_0x7f800000),
    kInstruction_sbc_al_r6_r6_0x7f800000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r8_0x00015600),
    kInstruction_sbc_al_r6_r8_0x00015600,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r0_0x00000ff0),
    kInstruction_sbc_al_r10_r0_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r1_0xffffffff),
    kInstruction_sbc_al_r8_r1_0xffffffff,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r7_0x00ab00ab),
    kInstruction_sbc_al_r3_r7_0x00ab00ab,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r11_0x01fe0000),
    kInstruction_sbc_al_r8_r11_0x01fe0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r1_0x00ff0000),
    kInstruction_sbc_al_r3_r1_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r4_0x000001fe),
    kInstruction_sbc_al_r5_r4_0x000001fe,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r10_0x00000558),
    kInstruction_sbc_al_r7_r10_0x00000558,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r13_0x00001560),
    kInstruction_sbc_al_r8_r13_0x00001560,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r4_0x00002ac0),
    kInstruction_sbc_al_r9_r4_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r7_0x03fc0000),
    kInstruction_sbc_al_r9_r7_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r12_0x2ac00000),
    kInstruction_sbc_al_r11_r12_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r10_0x00001fe0),
    kInstruction_sbc_al_r13_r10_0x00001fe0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r10_0x00558000),
    kInstruction_sbc_al_r11_r10_0x00558000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r2_0x000000ab),
    kInstruction_sbc_al_r3_r2_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r8_0x00000ab0),
    kInstruction_sbc_al_r0_r8_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r7_0xab000000),
    kInstruction_sbc_al_r9_r7_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r7_0x0ff00000),
    kInstruction_sbc_al_r11_r7_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r2_0x7f800000),
    kInstruction_sbc_al_r10_r2_0x7f800000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r1_0x05580000),
    kInstruction_sbc_al_r3_r1_0x05580000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r4_0x0ab00000),
    kInstruction_sbc_al_r1_r4_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r9_0x00005580),
    kInstruction_sbc_al_r4_r9_0x00005580,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r2_0x001fe000),
    kInstruction_sbc_al_r3_r2_0x001fe000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r6_0x00000156),
    kInstruction_sbc_al_r14_r6_0x00000156,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r3_0x00000ab0),
    kInstruction_sbc_al_r14_r3_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r13_0x000001fe),
    kInstruction_sbc_al_r12_r13_0x000001fe,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r10_0x1fe00000),
    kInstruction_sbc_al_r12_r10_0x1fe00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r9_0x2ac00000),
    kInstruction_sbc_al_r0_r9_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r6_0x00000156),
    kInstruction_sbc_al_r11_r6_0x00000156,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r4_0x3fc00000),
    kInstruction_sbc_al_r2_r4_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r13_0x00002ac0),
    kInstruction_sbc_al_r8_r13_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r5_0x00ff00ff),
    kInstruction_sbc_al_r1_r5_0x00ff00ff,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r1_0x0007f800),
    kInstruction_sbc_al_r6_r1_0x0007f800,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r1_0x00001fe0),
    kInstruction_sbc_al_r5_r1_0x00001fe0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r11_0xab00ab00),
    kInstruction_sbc_al_r8_r11_0xab00ab00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r0_0xff00ff00),
    kInstruction_sbc_al_r5_r0_0xff00ff00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r13_0x000000ab),
    kInstruction_sbc_al_r14_r13_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r4_0x05580000),
    kInstruction_sbc_al_r2_r4_0x05580000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r10_0x07f80000),
    kInstruction_sbc_al_r14_r10_0x07f80000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r3_0x55800000),
    kInstruction_sbc_al_r10_r3_0x55800000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r11_0x7f800000),
    kInstruction_sbc_al_r0_r11_0x7f800000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r12_0xffffffff),
    kInstruction_sbc_al_r3_r12_0xffffffff,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r3_0x00000558),
    kInstruction_sbc_al_r2_r3_0x00000558,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r2_0x0003fc00),
    kInstruction_sbc_al_r2_r2_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r10_0x15600000),
    kInstruction_sbc_al_r14_r10_0x15600000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r13_0x00000156),
    kInstruction_sbc_al_r3_r13_0x00000156,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r5_0x1fe00000),
    kInstruction_sbc_al_r10_r5_0x1fe00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r5_0x00055800),
    kInstruction_sbc_al_r1_r5_0x00055800,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r6_0xff000000),
    kInstruction_sbc_al_r8_r6_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r7_0x002ac000),
    kInstruction_sbc_al_r3_r7_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r4_0x00ff00ff),
    kInstruction_sbc_al_r6_r4_0x00ff00ff,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r8_0x0007f800),
    kInstruction_sbc_al_r0_r8_0x0007f800,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r3_0xff000000),
    kInstruction_sbc_al_r0_r3_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r1_0xabababab),
    kInstruction_sbc_al_r11_r1_0xabababab,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r10_0x000001fe),
    kInstruction_sbc_al_r14_r10_0x000001fe,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r11_0x002ac000),
    kInstruction_sbc_al_r4_r11_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r12_0x000000ab),
    kInstruction_sbc_al_r11_r12_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r4_0x003fc000),
    kInstruction_sbc_al_r3_r4_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r13_0x0ff00000),
    kInstruction_sbc_al_r3_r13_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r4_0x00001fe0),
    kInstruction_sbc_al_r5_r4_0x00001fe0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r12_0x002ac000),
    kInstruction_sbc_al_r6_r12_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r13_0x1fe00000),
    kInstruction_sbc_al_r13_r13_0x1fe00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r8_0x01560000),
    kInstruction_sbc_al_r0_r8_0x01560000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r7_0x00055800),
    kInstruction_sbc_al_r9_r7_0x00055800,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r0_0x00000156),
    kInstruction_sbc_al_r6_r0_0x00000156,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r12_0x00055800),
    kInstruction_sbc_al_r14_r12_0x00055800,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r0_0xab00ab00),
    kInstruction_sbc_al_r14_r0_0xab00ab00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r2_0x00ab0000),
    kInstruction_sbc_al_r14_r2_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r3_0x000000ab),
    kInstruction_sbc_al_r0_r3_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r4_0x003fc000),
    kInstruction_sbc_al_r13_r4_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r2_0x00001560),
    kInstruction_sbc_al_r4_r2_0x00001560,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r4_0x2ac00000),
    kInstruction_sbc_al_r14_r4_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r11_0x000003fc),
    kInstruction_sbc_al_r4_r11_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r8_0x001fe000),
    kInstruction_sbc_al_r6_r8_0x001fe000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r14_0x00000558),
    kInstruction_sbc_al_r12_r14_0x00000558,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r13_0x0ff00000),
    kInstruction_sbc_al_r0_r13_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r11_0xabababab),
    kInstruction_sbc_al_r3_r11_0xabababab,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r1_0x000001fe),
    kInstruction_sbc_al_r4_r1_0x000001fe,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r5_0x000002ac),
    kInstruction_sbc_al_r0_r5_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r5_0x0003fc00),
    kInstruction_sbc_al_r8_r5_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r13_0x0002ac00),
    kInstruction_sbc_al_r7_r13_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r6_0x00015600),
    kInstruction_sbc_al_r10_r6_0x00015600,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r10_0x00ff0000),
    kInstruction_sbc_al_r12_r10_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r12_0x00005580),
    kInstruction_sbc_al_r12_r12_0x00005580,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r4_0x02ac0000),
    kInstruction_sbc_al_r0_r4_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r9_0x02ac0000),
    kInstruction_sbc_al_r9_r9_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r4_0x00000558),
    kInstruction_sbc_al_r7_r4_0x00000558,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r14_0x07f80000),
    kInstruction_sbc_al_r12_r14_0x07f80000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r2_0xab00ab00),
    kInstruction_sbc_al_r7_r2_0xab00ab00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r12_0xff000000),
    kInstruction_sbc_al_r1_r12_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r0_0x7f800000),
    kInstruction_sbc_al_r8_r0_0x7f800000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r0_0x00000ab0),
    kInstruction_sbc_al_r7_r0_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r0_0x00005580),
    kInstruction_sbc_al_r1_r0_0x00005580,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r1_0x001fe000),
    kInstruction_sbc_al_r14_r1_0x001fe000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r13_0x0002ac00),
    kInstruction_sbc_al_r13_r13_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r12_0x0002ac00),
    kInstruction_sbc_al_r8_r12_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r10_0x00ff00ff),
    kInstruction_sbc_al_r10_r10_0x00ff00ff,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r4_0x002ac000),
    kInstruction_sbc_al_r4_r4_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r5_0x000ab000),
    kInstruction_sbc_al_r12_r5_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r2_0x000003fc),
    kInstruction_sbc_al_r1_r2_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r11_0x001fe000),
    kInstruction_sbc_al_r10_r11_0x001fe000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r2_0x05580000),
    kInstruction_sbc_al_r11_r2_0x05580000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r6_0x000000ab),
    kInstruction_sbc_al_r2_r6_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r3_0x0000ff00),
    kInstruction_sbc_al_r6_r3_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r0_0x00156000),
    kInstruction_sbc_al_r13_r0_0x00156000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r9_0x00002ac0),
    kInstruction_sbc_al_r2_r9_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r7_0x00055800),
    kInstruction_sbc_al_r11_r7_0x00055800,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r9_0x00001fe0),
    kInstruction_sbc_al_r10_r9_0x00001fe0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r11_0x00156000),
    kInstruction_sbc_al_r10_r11_0x00156000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r10_0xff00ff00),
    kInstruction_sbc_al_r12_r10_0xff00ff00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r14_0x00ab00ab),
    kInstruction_sbc_al_r7_r14_0x00ab00ab,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r7_0x002ac000),
    kInstruction_sbc_al_r14_r7_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r6_0x000ff000),
    kInstruction_sbc_al_r5_r6_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r1_0xff000000),
    kInstruction_sbc_al_r8_r1_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r0_0x000002ac),
    kInstruction_sbc_al_r8_r0_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r6_0x00002ac0),
    kInstruction_sbc_al_r12_r6_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r2_0x3fc00000),
    kInstruction_sbc_al_r14_r2_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r3_0x01560000),
    kInstruction_sbc_al_r3_r3_0x01560000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r12_0x0001fe00),
    kInstruction_sbc_al_r3_r12_0x0001fe00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r10_0x000002ac),
    kInstruction_sbc_al_r8_r10_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r9_0x002ac000),
    kInstruction_sbc_al_r9_r9_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r6_0x00156000),
    kInstruction_sbc_al_r0_r6_0x00156000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r7_0x0ff00000),
    kInstruction_sbc_al_r14_r7_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r3_0x00005580),
    kInstruction_sbc_al_r1_r3_0x00005580,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r7_0x000001fe),
    kInstruction_sbc_al_r14_r7_0x000001fe,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r5_0x03fc0000),
    kInstruction_sbc_al_r9_r5_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r14_0x002ac000),
    kInstruction_sbc_al_r7_r14_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r9_0x00000558),
    kInstruction_sbc_al_r8_r9_0x00000558,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r1_0x007f8000),
    kInstruction_sbc_al_r14_r1_0x007f8000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r0_0xab00ab00),
    kInstruction_sbc_al_r11_r0_0xab00ab00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r8_0x00000156),
    kInstruction_sbc_al_r11_r8_0x00000156,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r10_0x00055800),
    kInstruction_sbc_al_r4_r10_0x00055800,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r7_0x00007f80),
    kInstruction_sbc_al_r2_r7_0x00007f80,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r6_0x00558000),
    kInstruction_sbc_al_r0_r6_0x00558000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r2_0x00558000),
    kInstruction_sbc_al_r4_r2_0x00558000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r3_0x0007f800),
    kInstruction_sbc_al_r2_r3_0x0007f800,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r14_0xab00ab00),
    kInstruction_sbc_al_r14_r14_0xab00ab00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r13_0x000000ff),
    kInstruction_sbc_al_r0_r13_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r9_0xab00ab00),
    kInstruction_sbc_al_r10_r9_0xab00ab00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r1_0x3fc00000),
    kInstruction_sbc_al_r1_r1_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r6_0x002ac000),
    kInstruction_sbc_al_r8_r6_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r4_0x55800000),
    kInstruction_sbc_al_r12_r4_0x55800000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r10_0x2ac00000),
    kInstruction_sbc_al_r6_r10_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r9_0x001fe000),
    kInstruction_sbc_al_r7_r9_0x001fe000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r12_0x00005580),
    kInstruction_sbc_al_r4_r12_0x00005580,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r8_0x0ab00000),
    kInstruction_sbc_al_r9_r8_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r4_0xff00ff00),
    kInstruction_sbc_al_r2_r4_0xff00ff00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r14_0x00001fe0),
    kInstruction_sbc_al_r8_r14_0x00001fe0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r3_0x003fc000),
    kInstruction_sbc_al_r5_r3_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r10_0x00ff00ff),
    kInstruction_sbc_al_r2_r10_0x00ff00ff,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r12_0x15600000),
    kInstruction_sbc_al_r11_r12_0x15600000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r5_0x00002ac0),
    kInstruction_sbc_al_r1_r5_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r7_0x2ac00000),
    kInstruction_sbc_al_r3_r7_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r1_0xffffffff),
    kInstruction_sbc_al_r5_r1_0xffffffff,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r10_0xff00ff00),
    kInstruction_sbc_al_r4_r10_0xff00ff00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r2_0x00001fe0),
    kInstruction_sbc_al_r1_r2_0x00001fe0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r14_0x000000ff),
    kInstruction_sbc_al_r5_r14_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r0_0x000ab000),
    kInstruction_sbc_al_r14_r0_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r3_0x00ab0000),
    kInstruction_sbc_al_r10_r3_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r12_0x03fc0000),
    kInstruction_sbc_al_r10_r12_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r11_0x0007f800),
    kInstruction_sbc_al_r8_r11_0x0007f800,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r13_0x0001fe00),
    kInstruction_sbc_al_r9_r13_0x0001fe00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r13_0x02ac0000),
    kInstruction_sbc_al_r12_r13_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r9_0x00ab00ab),
    kInstruction_sbc_al_r3_r9_0x00ab00ab,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r1_0x3fc00000),
    kInstruction_sbc_al_r10_r1_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r8_0x00000558),
    kInstruction_sbc_al_r6_r8_0x00000558,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r12_0x0000ab00),
    kInstruction_sbc_al_r6_r12_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r13_0x000ab000),
    kInstruction_sbc_al_r14_r13_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r5_0x1fe00000),
    kInstruction_sbc_al_r1_r5_0x1fe00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r3_0x02ac0000),
    kInstruction_sbc_al_r11_r3_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r5_0x55800000),
    kInstruction_sbc_al_r9_r5_0x55800000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r5_0x000ab000),
    kInstruction_sbc_al_r5_r5_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r12_0x003fc000),
    kInstruction_sbc_al_r0_r12_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r4_0x0000ab00),
    kInstruction_sbc_al_r10_r4_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r2_0x0000ff00),
    kInstruction_sbc_al_r3_r2_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r8_0x3fc00000),
    kInstruction_sbc_al_r14_r8_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r13_0x05580000),
    kInstruction_sbc_al_r10_r13_0x05580000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r13_0x00156000),
    kInstruction_sbc_al_r4_r13_0x00156000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r2_0x000002ac),
    kInstruction_sbc_al_r7_r2_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r10_0x000002ac),
    kInstruction_sbc_al_r5_r10_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r0_0xab000000),
    kInstruction_sbc_al_r7_r0_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r10_0x000002ac),
    kInstruction_sbc_al_r1_r10_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r9_0x00002ac0),
    kInstruction_sbc_al_r11_r9_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r0_0x000001fe),
    kInstruction_sbc_al_r4_r0_0x000001fe,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r9_0x0003fc00),
    kInstruction_sbc_al_r11_r9_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r3_0x00005580),
    kInstruction_sbc_al_r8_r3_0x00005580,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r4_0xffffffff),
    kInstruction_sbc_al_r4_r4_0xffffffff,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r9_0x00000558),
    kInstruction_sbc_al_r1_r9_0x00000558,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r2_0x00ab0000),
    kInstruction_sbc_al_r9_r2_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r6_0x00003fc0),
    kInstruction_sbc_al_r11_r6_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r11_0x01fe0000),
    kInstruction_sbc_al_r11_r11_0x01fe0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r10_0x0001fe00),
    kInstruction_sbc_al_r6_r10_0x0001fe00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r3_0x00000156),
    kInstruction_sbc_al_r8_r3_0x00000156,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r12_0x0002ac00),
    kInstruction_sbc_al_r12_r12_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r6_0x7f800000),
    kInstruction_sbc_al_r8_r6_0x7f800000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r13_0x000002ac),
    kInstruction_sbc_al_r5_r13_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r13_0x15600000),
    kInstruction_sbc_al_r5_r13_0x15600000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r8_0x000000ab),
    kInstruction_sbc_al_r8_r8_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r14_0x00156000),
    kInstruction_sbc_al_r12_r14_0x00156000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r7_0x003fc000),
    kInstruction_sbc_al_r1_r7_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r0_0x00003fc0),
    kInstruction_sbc_al_r8_r0_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r11_0x0007f800),
    kInstruction_sbc_al_r14_r11_0x0007f800,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r8_0x00ab00ab),
    kInstruction_sbc_al_r3_r8_0x00ab00ab,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r8_0x55800000),
    kInstruction_sbc_al_r14_r8_0x55800000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r8_0x000ff000),
    kInstruction_sbc_al_r7_r8_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r11_0x01fe0000),
    kInstruction_sbc_al_r4_r11_0x01fe0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r4_0x01560000),
    kInstruction_sbc_al_r2_r4_0x01560000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r3_0xffffffff),
    kInstruction_sbc_al_r4_r3_0xffffffff,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r8_0xab000000),
    kInstruction_sbc_al_r7_r8_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r13_0x00000ab0),
    kInstruction_sbc_al_r0_r13_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r2_0x000001fe),
    kInstruction_sbc_al_r1_r2_0x000001fe,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r14_0x02ac0000),
    kInstruction_sbc_al_r8_r14_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r5_0x00558000),
    kInstruction_sbc_al_r4_r5_0x00558000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r7_0xff00ff00),
    kInstruction_sbc_al_r6_r7_0xff00ff00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r12_0x001fe000),
    kInstruction_sbc_al_r8_r12_0x001fe000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r4_0x07f80000),
    kInstruction_sbc_al_r6_r4_0x07f80000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r0_0x00001fe0),
    kInstruction_sbc_al_r4_r0_0x00001fe0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r3_0xff00ff00),
    kInstruction_sbc_al_r14_r3_0xff00ff00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r6_0xab000000),
    kInstruction_sbc_al_r0_r6_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r13_0x00000ab0),
    kInstruction_sbc_al_r12_r13_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r8_0x00000558),
    kInstruction_sbc_al_r12_r8_0x00000558,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r12_0x0003fc00),
    kInstruction_sbc_al_r3_r12_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r11_0x7f800000),
    kInstruction_sbc_al_r2_r11_0x7f800000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r4_0x15600000),
    kInstruction_sbc_al_r10_r4_0x15600000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r7_0x0ab00000),
    kInstruction_sbc_al_r8_r7_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r6_0x000000ff),
    kInstruction_sbc_al_r10_r6_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r4_0xff00ff00),
    kInstruction_sbc_al_r3_r4_0xff00ff00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r10_0x00ab0000),
    kInstruction_sbc_al_r14_r10_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r3_0x0002ac00),
    kInstruction_sbc_al_r8_r3_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r8_0x00000558),
    kInstruction_sbc_al_r8_r8_0x00000558,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r4_0x00015600),
    kInstruction_sbc_al_r12_r4_0x00015600,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r1_0x002ac000),
    kInstruction_sbc_al_r8_r1_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r5_0x000000ab),
    kInstruction_sbc_al_r8_r5_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r6_0x000000ab),
    kInstruction_sbc_al_r6_r6_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r7_0x00002ac0),
    kInstruction_sbc_al_r5_r7_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r4_0x00000ff0),
    kInstruction_sbc_al_r11_r4_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r9_0x00000ff0),
    kInstruction_sbc_al_r9_r9_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r8_0x00ff0000),
    kInstruction_sbc_al_r0_r8_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r11_0x000000ab),
    kInstruction_sbc_al_r9_r11_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r5_0x000000ff),
    kInstruction_sbc_al_r7_r5_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r0_0x15600000),
    kInstruction_sbc_al_r14_r0_0x15600000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r9_0x00000156),
    kInstruction_sbc_al_r10_r9_0x00000156,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r7_0x00ff0000),
    kInstruction_sbc_al_r3_r7_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r11_0xab00ab00),
    kInstruction_sbc_al_r6_r11_0xab00ab00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r2_0x002ac000),
    kInstruction_sbc_al_r5_r2_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r14_0x55800000),
    kInstruction_sbc_al_r9_r14_0x55800000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r13_0x15600000),
    kInstruction_sbc_al_r10_r13_0x15600000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r7_0x0ff00000),
    kInstruction_sbc_al_r13_r7_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r5_0xffffffff),
    kInstruction_sbc_al_r12_r5_0xffffffff,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r10_0x00000156),
    kInstruction_sbc_al_r8_r10_0x00000156,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r6_0x00005580),
    kInstruction_sbc_al_r7_r6_0x00005580,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r6_0x0ab00000),
    kInstruction_sbc_al_r6_r6_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r7_0x01fe0000),
    kInstruction_sbc_al_r3_r7_0x01fe0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r9_0x00558000),
    kInstruction_sbc_al_r14_r9_0x00558000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r13_0x000007f8),
    kInstruction_sbc_al_r3_r13_0x000007f8,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r2_0x00055800),
    kInstruction_sbc_al_r10_r2_0x00055800,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r14_0x00005580),
    kInstruction_sbc_al_r5_r14_0x00005580,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r12_0xab000000),
    kInstruction_sbc_al_r9_r12_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r14_0x00000156),
    kInstruction_sbc_al_r2_r14_0x00000156,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r10_0x000ff000),
    kInstruction_sbc_al_r6_r10_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r7_0x000007f8),
    kInstruction_sbc_al_r6_r7_0x000007f8,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r3_0x7f800000),
    kInstruction_sbc_al_r8_r3_0x7f800000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r12_0x15600000),
    kInstruction_sbc_al_r0_r12_0x15600000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r6_0x00558000),
    kInstruction_sbc_al_r1_r6_0x00558000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r8_0x55800000),
    kInstruction_sbc_al_r3_r8_0x55800000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r14_0x000003fc),
    kInstruction_sbc_al_r1_r14_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r2_0x0ab00000),
    kInstruction_sbc_al_r0_r2_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r12_0x00000156),
    kInstruction_sbc_al_r10_r12_0x00000156,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r14_0x03fc0000),
    kInstruction_sbc_al_r12_r14_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r5_0x0001fe00),
    kInstruction_sbc_al_r2_r5_0x0001fe00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r11_0x000ab000),
    kInstruction_sbc_al_r5_r11_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r14_0x0001fe00),
    kInstruction_sbc_al_r14_r14_0x0001fe00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r2_0x00003fc0),
    kInstruction_sbc_al_r13_r2_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r8_0xab000000),
    kInstruction_sbc_al_r0_r8_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r0_0x000000ab),
    kInstruction_sbc_al_r12_r0_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r10_0x002ac000),
    kInstruction_sbc_al_r11_r10_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r11_0x00ab0000),
    kInstruction_sbc_al_r12_r11_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r9_0x0ff00000),
    kInstruction_sbc_al_r2_r9_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r4_0x000001fe),
    kInstruction_sbc_al_r7_r4_0x000001fe,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r6_0x0000ff00),
    kInstruction_sbc_al_r7_r6_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r14_0x05580000),
    kInstruction_sbc_al_r11_r14_0x05580000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r10_0x00000558),
    kInstruction_sbc_al_r6_r10_0x00000558,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r6_0x0001fe00),
    kInstruction_sbc_al_r11_r6_0x0001fe00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r12_0xab00ab00),
    kInstruction_sbc_al_r11_r12_0xab00ab00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r8_0x7f800000),
    kInstruction_sbc_al_r1_r8_0x7f800000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r3_0x0000ff00),
    kInstruction_sbc_al_r4_r3_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r4_0x00ff00ff),
    kInstruction_sbc_al_r5_r4_0x00ff00ff,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r11_0x2ac00000),
    kInstruction_sbc_al_r12_r11_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r6_0xab00ab00),
    kInstruction_sbc_al_r1_r6_0xab00ab00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r3_0x000000ab),
    kInstruction_sbc_al_r6_r3_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r11_0x0007f800),
    kInstruction_sbc_al_r2_r11_0x0007f800,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r0_0x00001560),
    kInstruction_sbc_al_r3_r0_0x00001560,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r14_0x00000558),
    kInstruction_sbc_al_r1_r14_0x00000558,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r8_0x00558000),
    kInstruction_sbc_al_r10_r8_0x00558000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r8_0x000ff000),
    kInstruction_sbc_al_r0_r8_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r6_0x007f8000),
    kInstruction_sbc_al_r13_r6_0x007f8000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r10_0x000002ac),
    kInstruction_sbc_al_r3_r10_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r2_0x0003fc00),
    kInstruction_sbc_al_r12_r2_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r5_0x02ac0000),
    kInstruction_sbc_al_r5_r5_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r12_0x001fe000),
    kInstruction_sbc_al_r11_r12_0x001fe000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r14_0x001fe000),
    kInstruction_sbc_al_r0_r14_0x001fe000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r14_0x02ac0000),
    kInstruction_sbc_al_r0_r14_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r7_0x0ff00000),
    kInstruction_sbc_al_r6_r7_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r13_0x00000156),
    kInstruction_sbc_al_r10_r13_0x00000156,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r7_0x000007f8),
    kInstruction_sbc_al_r3_r7_0x000007f8,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r10_0x000000ab),
    kInstruction_sbc_al_r4_r10_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r6_0x00000558),
    kInstruction_sbc_al_r0_r6_0x00000558,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r1_0x05580000),
    kInstruction_sbc_al_r1_r1_0x05580000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r2_0x00001560),
    kInstruction_sbc_al_r8_r2_0x00001560,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r5_0x0001fe00),
    kInstruction_sbc_al_r9_r5_0x0001fe00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r9_0x0ab00000),
    kInstruction_sbc_al_r13_r9_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r9_0x00007f80),
    kInstruction_sbc_al_r13_r9_0x00007f80,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r5_0x0000ab00),
    kInstruction_sbc_al_r10_r5_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r13_0x007f8000),
    kInstruction_sbc_al_r6_r13_0x007f8000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r9_0x000ab000),
    kInstruction_sbc_al_r5_r9_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r4_0x000000ab),
    kInstruction_sbc_al_r4_r4_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r5_0xab00ab00),
    kInstruction_sbc_al_r13_r5_0xab00ab00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r3_0x00005580),
    kInstruction_sbc_al_r12_r3_0x00005580,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r10_0x55800000),
    kInstruction_sbc_al_r0_r10_0x55800000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r8_0x00ab00ab),
    kInstruction_sbc_al_r2_r8_0x00ab00ab,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r5_0x0003fc00),
    kInstruction_sbc_al_r11_r5_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r0_0x00ab0000),
    kInstruction_sbc_al_r11_r0_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r2_0x000002ac),
    kInstruction_sbc_al_r10_r2_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r12_0x00055800),
    kInstruction_sbc_al_r11_r12_0x00055800,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r13_0x00000ff0),
    kInstruction_sbc_al_r5_r13_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r14_0x15600000),
    kInstruction_sbc_al_r4_r14_0x15600000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r1_0x00003fc0),
    kInstruction_sbc_al_r10_r1_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r8_0xff000000),
    kInstruction_sbc_al_r14_r8_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r0_0x00ff0000),
    kInstruction_sbc_al_r12_r0_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r5_0x3fc00000),
    kInstruction_sbc_al_r4_r5_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r10_0x3fc00000),
    kInstruction_sbc_al_r14_r10_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r1_0x00015600),
    kInstruction_sbc_al_r10_r1_0x00015600,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r3_0xff000000),
    kInstruction_sbc_al_r4_r3_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r10_0x02ac0000),
    kInstruction_sbc_al_r10_r10_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r9_0x000ff000),
    kInstruction_sbc_al_r9_r9_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r7_0x0002ac00),
    kInstruction_sbc_al_r13_r7_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r8_0x00001fe0),
    kInstruction_sbc_al_r7_r8_0x00001fe0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r4_0x00001560),
    kInstruction_sbc_al_r2_r4_0x00001560,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r7_0x00156000),
    kInstruction_sbc_al_r13_r7_0x00156000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r9_0x000003fc),
    kInstruction_sbc_al_r9_r9_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r3_0x000ab000),
    kInstruction_sbc_al_r0_r3_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r12_0x0000ab00),
    kInstruction_sbc_al_r10_r12_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r13_0x00002ac0),
    kInstruction_sbc_al_r1_r13_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r10_0x001fe000),
    kInstruction_sbc_al_r3_r10_0x001fe000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r12_0x00ff00ff),
    kInstruction_sbc_al_r4_r12_0x00ff00ff,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r5_0x003fc000),
    kInstruction_sbc_al_r12_r5_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r2_0x0001fe00),
    kInstruction_sbc_al_r11_r2_0x0001fe00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r6_0x0007f800),
    kInstruction_sbc_al_r8_r6_0x0007f800,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r1_0x000000ff),
    kInstruction_sbc_al_r11_r1_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r5_r2_0x007f8000),
    kInstruction_sbc_al_r5_r2_0x007f8000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r10_0xab000000),
    kInstruction_sbc_al_r8_r10_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r3_0x000ff000),
    kInstruction_sbc_al_r10_r3_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r0_0x00ff0000),
    kInstruction_sbc_al_r6_r0_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r14_0x0ff00000),
    kInstruction_sbc_al_r7_r14_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r3_0x00001560),
    kInstruction_sbc_al_r8_r3_0x00001560,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r9_0x00000558),
    kInstruction_sbc_al_r13_r9_0x00000558,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r7_0x00001fe0),
    kInstruction_sbc_al_r8_r7_0x00001fe0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r3_0x0003fc00),
    kInstruction_sbc_al_r13_r3_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r14_0x000000ab),
    kInstruction_sbc_al_r4_r14_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r7_0x000000ab),
    kInstruction_sbc_al_r14_r7_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r9_0x00558000),
    kInstruction_sbc_al_r11_r9_0x00558000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r10_0x0000ff00),
    kInstruction_sbc_al_r3_r10_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r12_0x003fc000),
    kInstruction_sbc_al_r4_r12_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r1_0x002ac000),
    kInstruction_sbc_al_r11_r1_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r0_0x7f800000),
    kInstruction_sbc_al_r12_r0_0x7f800000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r9_0x00003fc0),
    kInstruction_sbc_al_r3_r9_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r6_0x0ff00000),
    kInstruction_sbc_al_r6_r6_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r11_0xff000000),
    kInstruction_sbc_al_r1_r11_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r10_0x0007f800),
    kInstruction_sbc_al_r2_r10_0x0007f800,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r10_0x000002ac),
    kInstruction_sbc_al_r12_r10_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r8_0x000003fc),
    kInstruction_sbc_al_r10_r8_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r0_0x55800000),
    kInstruction_sbc_al_r9_r0_0x55800000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r7_0x1fe00000),
    kInstruction_sbc_al_r8_r7_0x1fe00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r0_0x15600000),
    kInstruction_sbc_al_r4_r0_0x15600000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r0_0xff00ff00),
    kInstruction_sbc_al_r4_r0_0xff00ff00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r14_0x00007f80),
    kInstruction_sbc_al_r1_r14_0x00007f80,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r3_0x00ff00ff),
    kInstruction_sbc_al_r7_r3_0x00ff00ff,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r2_0x00001560),
    kInstruction_sbc_al_r10_r2_0x00001560,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r14_0xabababab),
    kInstruction_sbc_al_r0_r14_0xabababab,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r4_0x007f8000),
    kInstruction_sbc_al_r3_r4_0x007f8000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r2_0x003fc000),
    kInstruction_sbc_al_r0_r2_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r6_0x0002ac00),
    kInstruction_sbc_al_r13_r6_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r5_0x00001fe0),
    kInstruction_sbc_al_r11_r5_0x00001fe0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r13_0x00005580),
    kInstruction_sbc_al_r1_r13_0x00005580,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r8_0x000007f8),
    kInstruction_sbc_al_r13_r8_0x000007f8,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r4_0x0ab00000),
    kInstruction_sbc_al_r6_r4_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r10_0x1fe00000),
    kInstruction_sbc_al_r14_r10_0x1fe00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r6_0xff00ff00),
    kInstruction_sbc_al_r7_r6_0xff00ff00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r5_0xffffffff),
    kInstruction_sbc_al_r11_r5_0xffffffff,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r12_0xffffffff),
    kInstruction_sbc_al_r0_r12_0xffffffff,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r2_0x15600000),
    kInstruction_sbc_al_r12_r2_0x15600000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r3_r12_0x000ff000),
    kInstruction_sbc_al_r3_r12_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r6_r8_0x00055800),
    kInstruction_sbc_al_r6_r8_0x00055800,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r7_0x05580000),
    kInstruction_sbc_al_r12_r7_0x05580000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r5_0x007f8000),
    kInstruction_sbc_al_r8_r5_0x007f8000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r1_0x000ab000),
    kInstruction_sbc_al_r4_r1_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r12_0x02ac0000),
    kInstruction_sbc_al_r13_r12_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r8_0x000000ff),
    kInstruction_sbc_al_r9_r8_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r1_r11_0x00005580),
    kInstruction_sbc_al_r1_r11_0x00005580,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r12_0x02ac0000),
    kInstruction_sbc_al_r10_r12_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r7_r9_0x00ab00ab),
    kInstruction_sbc_al_r7_r9_0x00ab00ab,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r5_0x0000ab00),
    kInstruction_sbc_al_r0_r5_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r13_r9_0x00558000),
    kInstruction_sbc_al_r13_r9_0x00558000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r0_r1_0x002ac000),
    kInstruction_sbc_al_r0_r1_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r14_r1_0x00000ab0),
    kInstruction_sbc_al_r14_r1_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r2_r2_0x00000558),
    kInstruction_sbc_al_r2_r2_0x00000558,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r13_0x00ab00ab),
    kInstruction_sbc_al_r10_r13_0x00ab00ab,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r6_0x00001560),
    kInstruction_sbc_al_r4_r6_0x00001560,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r0_0x00156000),
    kInstruction_sbc_al_r10_r0_0x00156000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r10_r13_0x00156000),
    kInstruction_sbc_al_r10_r13_0x00156000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r11_r2_0x001fe000),
    kInstruction_sbc_al_r11_r2_0x001fe000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r4_r5_0x2ac00000),
    kInstruction_sbc_al_r4_r5_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r8_0x02ac0000),
    kInstruction_sbc_al_r8_r8_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r1_0x7f800000),
    kInstruction_sbc_al_r9_r1_0x7f800000,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r8_r9_0xff00ff00),
    kInstruction_sbc_al_r8_r9_0xff00ff00,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r12_r7_0x00ff00ff),
    kInstruction_sbc_al_r12_r7_0x00ff00ff,
  },
  {
    ARRAY_SIZE(kInstruction_sbc_al_r9_r10_0x00156000),
    kInstruction_sbc_al_r9_r10_0x00156000,
  },
};

#endif  // VIXL_ASSEMBLER_COND_RD_RN_OPERAND_CONST_SBC_T32_H_
